'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var icons = require('@material-ui/icons');
var lab = require('@material-ui/lab');
var ui = require('@superdispatch/ui');
var react = require('react');
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var jsxRuntime = require('react/jsx-runtime');
var _objectSpread = _interopDefault(require('@babel/runtime/helpers/objectSpread2'));
var _objectWithoutProperties = _interopDefault(require('@babel/runtime/helpers/objectWithoutProperties'));
var reactTransitionGroup = require('react-transition-group');
var core = require('@material-ui/core');
var dates = require('@superdispatch/dates');
var uiLab = require('@superdispatch/ui-lab');
var js = require('@mdi/js');
var Dropzone = _interopDefault(require('react-dropzone'));
var reactAnchorme = require('react-anchorme');
var lodash = require('lodash');

function colorMixin(textColor, iconColor, backgroundColor, buttonHoverColor) {
  return styled.css(["color:", ";border-color:", ";background-color:", ";& .MuiAlert-icon{color:", ";}& .MuiAlert-action{color:", ";& .MuiIconButton-root{&:hover,&:active{color:", ";}}}"], textColor, textColor, backgroundColor, iconColor, iconColor, buttonHoverColor);
}
var StyledAlert = /*#__PURE__*/styled__default(lab.Alert).withConfig({
  displayName: "Alert__StyledAlert",
  componentId: "SD__sc-1j6qebb-0"
})(["&.MuiAlert-outlinedSuccess{", ";}&.MuiAlert-outlinedInfo{", ";}&.MuiAlert-outlinedWarning{", ";}&.MuiAlert-outlinedError{", ";}& .MuiAlert-icon{opacity:1;padding:8px 0;font-size:24px;}& .MuiAlert-action{display:block;padding-top:5px;margin-right:-3px;& .MuiIconButton-root{& .MuiSvgIcon-root{font-size:24px;}}}"], /*#__PURE__*/colorMixin(ui.ColorDynamic.Green500, ui.ColorDynamic.Green300, ui.ColorDynamic.Green50, ui.ColorDynamic.Green400), /*#__PURE__*/colorMixin(ui.ColorDynamic.Blue500, ui.ColorDynamic.Blue300, ui.ColorDynamic.Blue50, ui.ColorDynamic.Blue400), /*#__PURE__*/colorMixin(ui.ColorDynamic.Yellow500, ui.ColorDynamic.Yellow300, ui.ColorDynamic.Yellow50, ui.ColorDynamic.Yellow400), /*#__PURE__*/colorMixin(ui.ColorDynamic.Red500, ui.ColorDynamic.Red300, ui.ColorDynamic.Red50, ui.ColorDynamic.Red400));
function toMaterialSeverity(severity) {
  return severity === 'info' ? 'info' : severity === 'caution' ? 'warning' : severity === 'critical' ? 'error' : 'success';
}
var iconMapping = {
  success: /*#__PURE__*/jsxRuntime.jsx(icons.CheckCircle, {}),
  info: /*#__PURE__*/jsxRuntime.jsx(icons.Info, {}),
  error: /*#__PURE__*/jsxRuntime.jsx(icons.Error, {}),
  warning: /*#__PURE__*/jsxRuntime.jsx(icons.WarningRounded, {})
};
var Alert = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    children,
    onClose,
    severity = 'positive',
    icon
  } = _ref;
  return /*#__PURE__*/jsxRuntime.jsx(StyledAlert, {
    ref: ref,
    variant: "outlined",
    icon: icon,
    iconMapping: iconMapping,
    severity: toMaterialSeverity(severity),
    onClose: onClose,
    children: children
  });
});
if (process.env.NODE_ENV !== "production") Alert.displayName = "Alert";

var _excluded = ["children"],
  _excluded2 = ["in"];
function enterMixin(border) {
  return styled.css(["min-height:56px;color:", ";background-color:", ";border-", ":1px #dfe3e8 solid;"], ui.ColorDynamic.Dark500, ui.ColorDynamic.White, border);
}
function enterAnimation(border) {
  return styled.keyframes(["0%{min-height:0;color:", ";background-color:", ";}50%{min-height:56px;color:", ";background-color:", ";}70%{min-height:56px;color:", ";background-color:", ";}100%{", "}"], ui.ColorDynamic.White, ui.ColorDynamic.Dark500, ui.ColorDynamic.White, ui.ColorDynamic.Dark500, ui.ColorDynamic.White, ui.ColorDynamic.Dark500, enterMixin(border));
}
var CustomTransition = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
      children
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded);
  return /*#__PURE__*/jsxRuntime.jsx(reactTransitionGroup.CSSTransition, _objectSpread(_objectSpread({}, props), {}, {
    ref: ref,
    timeout: 3000,
    classNames: props.className,
    children: /*#__PURE__*/jsxRuntime.jsx("div", {
      children: children
    })
  }));
});
if (process.env.NODE_ENV !== "production") CustomTransition.displayName = "CustomTransition";
var BannerContent = /*#__PURE__*/styled__default(CustomTransition).withConfig({
  displayName: "Banner__BannerContent",
  componentId: "SD__sc-9kw31n-0"
})(_ref2 => {
  var {
    border = 'bottom'
  } = _ref2;
  return styled.css(["height:0;width:100%;overflow:hidden;display:flex;align-items:center;justify-content:center;color:", ";background-color:", ";&-enter-active{animation:", " 2s 1s forwards;}&-enter-done{", ";}&-exit{", ";}&-exit-active{min-height:0;transition:min-height 2s 1s;}"], ui.ColorDynamic.White, ui.ColorDynamic.White, enterAnimation(border), enterMixin(border), enterMixin(border));
});
var Banner = /*#__PURE__*/react.forwardRef((_ref3, ref) => {
  var {
      in: inProp
    } = _ref3,
    props = _objectWithoutProperties(_ref3, _excluded2);
  var [isIn, setIn] = react.useState(false);

  // transition is not triggered on initial render with `in: true`
  react.useEffect(() => {
    setIn(!!inProp);
  }, [inProp]);
  return /*#__PURE__*/jsxRuntime.jsx(BannerContent, _objectSpread({
    ref: ref,
    in: isIn
  }, props));
});
if (process.env.NODE_ENV !== "production") Banner.displayName = "Banner";

function createRuleNormalizer(rules) {
  return input => {
    if (typeof input == 'string') {
      var value = rules[input];
      if (typeof value == 'number') {
        return "".concat(value, "px");
      }
      if (typeof value == 'string') {
        return value;
      }
    }
    return undefined;
  };
}

//
// Colors
//

function normalizeColor(input) {
  return ui.isColorDynamicProp(input) ? ui.ColorDynamic[input] : undefined;
}

//
// Space
//

function parseSpace(space) {
  return "".concat(ui.parseSpaceProp(space), "px");
}

//
// Margins
//

function parseMargin(input) {
  if (input === 'auto') return input;
  var prefix = '';
  if (typeof input == 'string' && input.startsWith('-')) {
    prefix = '-';
    input = input.slice(1);
  }
  return prefix + parseSpace(input);
}

//
// Borders
//

var normalizeBorderRadius = /*#__PURE__*/createRuleNormalizer({
  none: 0,
  small: 4,
  medium: 8
});
var normalizeBorderWidth = /*#__PURE__*/createRuleNormalizer({
  none: 0,
  small: 1,
  medium: 2,
  large: 4
});

//
// Rules
//

var normalizers = {
  display: undefined,
  color: normalizeColor,
  backgroundColor: normalizeColor,
  borderColor: normalizeColor,
  borderTopColor: normalizeColor,
  borderLeftColor: normalizeColor,
  borderRightColor: normalizeColor,
  borderBottomColor: normalizeColor,
  borderWidth: normalizeBorderWidth,
  borderTopWidth: normalizeBorderWidth,
  borderLeftWidth: normalizeBorderWidth,
  borderRightWidth: normalizeBorderWidth,
  borderBottomWidth: normalizeBorderWidth,
  margin: parseMargin,
  marginTop: parseMargin,
  marginLeft: parseMargin,
  marginRight: parseMargin,
  marginBottom: parseMargin,
  padding: parseSpace,
  paddingTop: parseSpace,
  paddingLeft: parseSpace,
  paddingRight: parseSpace,
  paddingBottom: parseSpace,
  borderRadius: normalizeBorderRadius,
  borderTopLeftRadius: normalizeBorderRadius,
  borderTopRightRadius: normalizeBorderRadius,
  borderBottomLeftRadius: normalizeBorderRadius,
  borderBottomRightRadius: normalizeBorderRadius,
  fontSize: undefined,
  width: undefined,
  maxWidth: undefined,
  minWidth: undefined,
  height: undefined,
  maxHeight: undefined,
  minHeight: undefined,
  overflow: undefined,
  overflowY: undefined,
  overflowX: undefined,
  top: undefined,
  left: undefined,
  right: undefined,
  bottom: undefined,
  position: undefined,
  alignItems: undefined,
  justifyContent: undefined
};
function injectRule(styles, key, breakpoint, value, normalizer) {
  if (normalizer != null) value = normalizer(value);
  if (value != null) {
    var rules = styles[breakpoint];
    if (typeof rules != 'object') {
      rules = {};
      styles[breakpoint] = rules;
    }
    rules[key] = String(value);
  }
}

//
// Box
//

var Box = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "Box",
  componentId: "SD__sc-1bc600y-0"
})(props => {
  var {
    breakpoints
  } = props.theme;
  var xs = breakpoints.up('xs');
  var sm = breakpoints.up('sm');
  var md = breakpoints.up('md');
  var styles = {
    margin: 0,
    padding: 0,
    borderWidth: 0,
    borderStyle: 'solid'
  };
  for (var k in props) {
    if (Object.prototype.hasOwnProperty.call(props, k) && k in normalizers) {
      var key = k;
      var prop = props[key];
      if (prop != null) {
        var [mobile, tablet, desktop] = ui.parseResponsiveProp(prop);
        var normalizer = normalizers[key];
        injectRule(styles, key, xs, mobile, normalizer);
        injectRule(styles, key, sm, tablet, normalizer);
        injectRule(styles, key, md, desktop, normalizer);
      }
    }
  }
  return styles;
});

var _excluded$1 = ["icon", "children", "variant", "active", "disabled", "fullWidth"];
var ButtonRoot = /*#__PURE__*/styled__default(core.ButtonBase).withConfig({
  displayName: "ButtonArea__ButtonRoot",
  componentId: "SD__sc-1czum63-0"
})(["padding:12px 32px;border-width:1px;border-radius:4px;border-style:solid;border-color:", ";color:", ";background-color:", ";& svg{color:inherit;font-size:24px;}&[data-full-width='true']{width:100%;}&[data-disabled='true']{color:", ";border-color:", ";}&[data-variant='success']{&:hover{color:", ";box-shadow:0 0 0 2px ", ";border-color:", ";}&[data-active='true']{color:", ";border-color:", ";background-color:", ";}}&[data-variant='danger']{&:hover{color:", ";box-shadow:0 0 0 2px ", ";border-color:", ";}&[data-active='true']{color:", ";border-color:", ";background-color:", ";}}"], ui.ColorDynamic.Silver500, ui.ColorDynamic.Dark100, ui.ColorDynamic.White, ui.ColorDynamic.Silver500, ui.ColorDynamic.Silver400, ui.ColorDynamic.Green300, ui.ColorDynamic.Green100, ui.ColorDynamic.Green300, ui.ColorDynamic.Green300, ui.ColorDynamic.Green300, ui.ColorDynamic.Green50, ui.ColorDynamic.Red300, ui.ColorDynamic.Red100, ui.ColorDynamic.Red300, ui.ColorDynamic.Red300, ui.ColorDynamic.Red300, ui.ColorDynamic.Red50);
var ButtonArea = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
      icon,
      children,
      variant,
      active,
      disabled,
      fullWidth
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded$1);
  return /*#__PURE__*/jsxRuntime.jsx(ButtonRoot, _objectSpread(_objectSpread({
    ref: ref,
    disabled: disabled,
    "data-active": active,
    "data-disabled": disabled,
    "data-variant": variant,
    "data-full-width": fullWidth
  }, props), {}, {
    children: /*#__PURE__*/jsxRuntime.jsxs(ui.Stack, {
      align: "center",
      space: "xxsmall",
      children: [icon, /*#__PURE__*/jsxRuntime.jsx(core.Typography, {
        variant: "h4",
        color: disabled ? 'inherit' : 'textPrimary',
        children: children
      })]
    })
  }));
});
if (process.env.NODE_ENV !== "production") ButtonArea.displayName = "ButtonArea";

var _excluded$2 = ["children", "endIcon", "startIcon", "tabIndex", "active", "pending", "disabled", "size", "fullWidth", "variant"],
  _excluded2$1 = ["type"],
  _excluded3 = ["href", "target"];
function createButtonVariables(size, _ref) {
  var {
    fontSize = size === 'large' ? 16 : 14,
    lineHeight = size === 'large' ? 24 : 20,
    fontSizeMobile = size === 'large' ? 18 : 16,
    lineHeightMobile = size === 'large' ? 28 : 24,
    paddingX = size === 'large' ? 32 : 16,
    paddingY = size === 'large' ? 8 : size === 'small' ? 2 : 6,
    paddingXMobile = size === 'large' ? 64 : 24,
    paddingYMobile = size === 'large' ? 14 : size === 'small' ? 4 : 10,
    textColor = ui.ColorDynamic.Transparent,
    textColorHovered = textColor,
    textColorDisabled = textColor,
    iconColor = textColor,
    outlineColor = ui.ColorDynamic.Transparent,
    borderColor = ui.ColorDynamic.Transparent,
    borderColorHovered = borderColor,
    borderColorDisabled = borderColor,
    backgroundColor = ui.ColorDynamic.Transparent,
    backgroundColorHovered = backgroundColor,
    backgroundColorActive = backgroundColorHovered,
    backgroundColorDisabled = backgroundColor
  } = _ref;
  return {
    paddingX,
    paddingY,
    fontSize,
    lineHeight,
    paddingXMobile,
    paddingYMobile,
    fontSizeMobile,
    lineHeightMobile,
    textColor,
    borderColor,
    outlineColor,
    backgroundColor,
    textColorHovered,
    borderColorHovered,
    backgroundColorHovered,
    backgroundColorActive,
    textColorDisabled,
    borderColorDisabled,
    backgroundColorDisabled,
    iconColor
  };
}
function getDefaultVariables(size) {
  return createButtonVariables(size, {
    textColor: ui.Color.White,
    outlineColor: ui.ColorDynamic.Blue30,
    backgroundColor: ui.ColorDynamic.Blue300,
    textColorHovered: ui.Color.White,
    backgroundColorHovered: ui.ColorDynamic.Blue500,
    backgroundColorActive: ui.ColorDynamic.Blue400,
    textColorDisabled: ui.Color.White50,
    backgroundColorDisabled: ui.ColorDynamic.Blue30
  });
}
function getPrimaryVariables(size) {
  return getDefaultVariables(size);
}
function getNeutralVariables(size) {
  return createButtonVariables(size, {
    textColor: ui.ColorDynamic.Dark500,
    borderColor: ui.ColorDynamic.Silver500,
    outlineColor: ui.ColorDynamic.Blue30,
    backgroundColor: ui.ColorDynamic.White,
    textColorHovered: ui.ColorDynamic.Blue500,
    borderColorHovered: ui.ColorDynamic.Blue500,
    backgroundColorHovered: ui.ColorDynamic.Blue50,
    backgroundColorActive: ui.ColorDynamic.Blue50,
    textColorDisabled: ui.ColorDynamic.Silver500,
    iconColor: ui.ColorDynamic.Dark100
  });
}
function getCriticalVariables(size) {
  return createButtonVariables(size, {
    textColor: ui.ColorDynamic.Red500,
    borderColor: ui.ColorDynamic.Red500,
    outlineColor: ui.ColorDynamic.Red30,
    backgroundColor: ui.ColorDynamic.Red50,
    backgroundColorHovered: ui.ColorDynamic.Red300Aplha20,
    backgroundColorActive: ui.ColorDynamic.Red10,
    textColorDisabled: ui.ColorDynamic.Red30,
    borderColorDisabled: ui.ColorDynamic.Red30,
    backgroundColorDisabled: ui.ColorDynamic.Red50
  });
}
function getTextVariables(size) {
  return createButtonVariables(size, {
    textColor: ui.ColorDynamic.Blue500,
    outlineColor: ui.ColorDynamic.Blue30,
    textColorHovered: ui.ColorDynamic.Blue500,
    backgroundColorHovered: ui.ColorDynamic.Blue50,
    backgroundColorActive: ui.ColorDynamic.Blue50,
    textColorDisabled: ui.ColorDynamic.Blue30
  });
}
function getInvertedVariables(size) {
  return createButtonVariables(size, {
    textColor: ui.ColorDynamic.White,
    outlineColor: ui.ColorDynamic.White40,
    backgroundColor: ui.ColorDynamic.White20,
    textColorHovered: ui.ColorDynamic.White,
    backgroundColorHovered: ui.ColorDynamic.White40,
    backgroundColorActive: ui.ColorDynamic.White20,
    textColorDisabled: ui.ColorDynamic.White50,
    backgroundColorDisabled: ui.ColorDynamic.White08
  });
}
function getSuccessVariables(size) {
  return createButtonVariables(size, {
    textColor: ui.Color.White,
    outlineColor: ui.ColorDynamic.Green30,
    backgroundColor: ui.ColorDynamic.Green300,
    backgroundColorHovered: ui.ColorDynamic.Green500,
    backgroundColorActive: ui.ColorDynamic.Green500,
    textColorDisabled: ui.Color.White50,
    backgroundColorDisabled: ui.ColorDynamic.Green30
  });
}
var ButtonRoot$1 = /*#__PURE__*/styled__default.button.withConfig({
  displayName: "Button__ButtonRoot",
  componentId: "SD__sc-1pwdpe3-0"
})(_ref2 => {
  var {
    size,
    theme,
    variant,
    fullWidth
  } = _ref2;
  var variables = variant === 'primary' ? getPrimaryVariables(size) : variant === 'neutral' ? getNeutralVariables(size) : variant === 'critical' ? getCriticalVariables(size) : variant === 'text' ? getTextVariables(size) : variant === 'inverted' ? getInvertedVariables(size) : variant === 'success' ? getSuccessVariables(size) : getDefaultVariables(size);
  return styled.css(JSON.parse('["border:0;margin:0;outline:0;position:relative;vertical-align:middle;cursor:pointer;text-decoration:none;&[aria-disabled=\'true\']{cursor:default;pointer-events:none;}-moz-appearance:none;&::-moz-focus-inner{border-style:none;}-webkit-appearance:none;-webkit-user-select:none;-webkit-tap-highlight-color:transparent;@media print{-webkit-print-color-adjust:exact;}--button-visibility:visible;--button-text-color:",";--button-border-color:",";--button-outline-color:",";--button-background-color:",";--button-icon-color:",";--button-padding-x:","px;--button-padding-y:","px;--button-font-size:","px;--button-line-height:","px;","{--button-padding-x:","px;--button-padding-y:","px;--button-font-size:","px;--button-line-height:","px;}&[aria-disabled=\'true\']{--button-text-color:",";--button-border-color:",";--button-background-color:",";--button-icon-color:",";&[aria-busy=\'true\']{--button-visibility:hidden;}}&[aria-disabled=\'false\']{&[aria-expanded=\'true\']{--button-text-color:",";--button-border-color:",";--button-background-color:",";--button-icon-color:",";}&,&[aria-expanded=\'true\']{&:focus{--button-outline-color:",";}@media (hover:hover) and (pointer:fine){&:hover{--button-text-color:",";--button-border-color:",";--button-background-color:",";span{svg{fill:",";}}}}&:active{--button-background-color:",";}}}display:inline-flex;align-items:center;justify-content:center;min-width:48px;width:",";border-radius:4px;font-family:",";font-weight:",";color:var(--button-text-color);background-color:var(--button-background-color);font-size:var(--button-font-size);line-height:var(--button-line-height);padding:var(--button-padding-y) var(--button-padding-x);box-shadow:inset 0 0 0 1px var(--button-border-color),0 0 0 2px var(--button-outline-color);transition:",";"]'), variables.textColor, variables.borderColor, ui.ColorDynamic.Transparent, variables.backgroundColor, variables.iconColor, variables.paddingXMobile, variables.paddingYMobile, variables.fontSizeMobile, variables.lineHeightMobile, theme.breakpoints.up('sm'), variables.paddingX, variables.paddingY, variables.fontSize, variables.lineHeight, variables.textColorDisabled, variables.borderColorDisabled, variables.backgroundColorDisabled, variables.textColorDisabled, variables.textColorHovered, variables.borderColorHovered, variables.backgroundColorHovered, variables.textColorHovered, variables.outlineColor, variables.textColorHovered, variables.borderColorHovered, variables.backgroundColorHovered, variables.textColorHovered, variables.backgroundColorActive, fullWidth ? '100%' : 'auto', theme.typography.fontFamily, theme.typography.fontWeightBold, theme.transitions.create(['color', 'box-shadow', 'background-color']));
});
var ButtonLabel = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "Button__ButtonLabel",
  componentId: "SD__sc-1pwdpe3-1"
})(["display:inherit;align-items:inherit;justify-content:inherit;visibility:var(--button-visibility);--mui-svg-icon-size:var(--button-line-height);"]);
var ButtonStartIcon = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "Button__ButtonStartIcon",
  componentId: "SD__sc-1pwdpe3-2"
})(["margin-right:4px;color:var(--button-icon-color);"]);
var ButtonEndIcon = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "Button__ButtonEndIcon",
  componentId: "SD__sc-1pwdpe3-3"
})(["margin-left:4px;color:var(--button-icon-color);"]);
var ButtonPendingIndicator = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "Button__ButtonPendingIndicator",
  componentId: "SD__sc-1pwdpe3-4"
})(["left:50%;display:flex;position:absolute;visibility:visible;transform:translate(-50%);"]);
function useButtonProps(_ref3) {
  var {
      children,
      endIcon,
      startIcon,
      tabIndex: tabIndexProp = 0,
      active = false,
      pending = false,
      disabled: disabledProp = false,
      size = 'medium',
      fullWidth = false,
      variant = 'default'
    } = _ref3,
    props = _objectWithoutProperties(_ref3, _excluded$2);
  var disabled = pending || disabledProp;
  var tabIndex = disabled ? -1 : tabIndexProp;
  return _objectSpread(_objectSpread({}, props), {}, {
    size,
    variant,
    fullWidth,
    tabIndex,
    disabled,
    'aria-busy': pending,
    'aria-expanded': active,
    'aria-disabled': disabled,
    children: /*#__PURE__*/jsxRuntime.jsxs(ButtonLabel, {
      children: [!!startIcon && /*#__PURE__*/jsxRuntime.jsx(ButtonStartIcon, {
        children: startIcon
      }), children, !!endIcon && /*#__PURE__*/jsxRuntime.jsx(ButtonEndIcon, {
        children: endIcon
      }), pending && /*#__PURE__*/jsxRuntime.jsx(ButtonPendingIndicator, {
        children: /*#__PURE__*/jsxRuntime.jsx(core.CircularProgress, {
          size: "1em",
          color: "inherit"
        })
      })]
    })
  });
}
var Button = /*#__PURE__*/react.forwardRef((_ref4, ref) => {
  var {
      type = 'button'
    } = _ref4,
    props = _objectWithoutProperties(_ref4, _excluded2$1);
  var buttonProps = useButtonProps(props);
  return /*#__PURE__*/jsxRuntime.jsx(ButtonRoot$1, _objectSpread(_objectSpread({}, buttonProps), {}, {
    ref: ref,
    type: type
  }));
});
if (process.env.NODE_ENV !== "production") Button.displayName = "Button";
var AnchorButton = /*#__PURE__*/react.forwardRef((_ref5, ref) => {
  var {
      href,
      target
    } = _ref5,
    props = _objectWithoutProperties(_ref5, _excluded3);
  var buttonProps = useButtonProps(props);
  var rel = target === '_blank' ? 'noopener noreferrer' : undefined;
  return /*#__PURE__*/jsxRuntime.jsx(ButtonRoot$1, _objectSpread(_objectSpread({}, buttonProps), {}, {
    as: "a",
    ref: ref,
    rel: rel,
    href: href,
    target: target
  }));
});
if (process.env.NODE_ENV !== "production") AnchorButton.displayName = "AnchorButton";

var ChatContainer = /*#__PURE__*/styled__default('div').withConfig({
  displayName: "Chat__ChatContainer",
  componentId: "SD__sc-qksih8-0"
})(_ref => {
  var {
    isEmpty
  } = _ref;
  return "\n  display: flex;\n  flex-direction: column-reverse;\n  overflow: auto;\n  justify-content: ".concat(isEmpty ? 'center' : 'end', ";\n  width: 100%;\n  height: 100%;\n  min-width: 300px;\n  max-width: 560px;\n  min-height: 368px;\n  max-height: 696px;\n  padding: 16px;\n  box-sizing: border-box;\n");
});
function emptyPlaceholder(text) {
  return /*#__PURE__*/jsxRuntime.jsx(core.Typography, {
    color: "textSecondary",
    align: "center",
    children: text
  });
}
var Chat = /*#__PURE__*/react.forwardRef((_ref2, ref) => {
  var {
    children,
    className,
    emptyText = 'No new messages'
  } = _ref2;
  var isEmpty = react.Children.toArray(children).length === 0;
  return /*#__PURE__*/jsxRuntime.jsx(ChatContainer, {
    "data-testid": "chat-container",
    isEmpty: isEmpty,
    ref: ref,
    className: className,
    children: /*#__PURE__*/jsxRuntime.jsx(ui.Stack, {
      space: "small",
      children: isEmpty ? emptyPlaceholder(emptyText) : children
    })
  });
});
if (process.env.NODE_ENV !== "production") Chat.displayName = "Chat";
Chat.displayName = 'Chat';

var ChatMessage = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    author,
    role,
    dateTime,
    text,
    variant
  } = _ref;
  var time = dates.formatDate(dateTime, {
    variant: 'Time'
  });
  return /*#__PURE__*/jsxRuntime.jsxs(ui.Stack, {
    space: "xxsmall",
    align: variant === 'outgoing' ? 'right' : 'left',
    ref: ref,
    "data-testid": "chat-message",
    children: [/*#__PURE__*/jsxRuntime.jsxs(ui.Inline, {
      verticalAlign: "center",
      children: [/*#__PURE__*/jsxRuntime.jsx(core.Typography, {
        color: "textPrimary",
        children: author
      }), /*#__PURE__*/jsxRuntime.jsx(core.Typography, {
        color: "textSecondary",
        children: role
      }), /*#__PURE__*/jsxRuntime.jsx(core.Typography, {
        color: "textSecondary",
        children: time
      })]
    }), /*#__PURE__*/jsxRuntime.jsx(uiLab.Box, {
      display: "inline-block",
      padding: "xsmall",
      marginTop: "none",
      borderRadius: "medium",
      backgroundColor: variant === 'outgoing' ? 'Blue50' : 'Silver200',
      children: /*#__PURE__*/jsxRuntime.jsx(core.Typography, {
        color: "textPrimary",
        children: text
      })
    })]
  });
});
if (process.env.NODE_ENV !== "production") ChatMessage.displayName = "ChatMessage";
ChatMessage.displayName = 'ChatMessage';

var _excluded$3 = ["fullViewportHeight"];
var Container = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
      fullViewportHeight
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded$3);
  var nodeRef = react.useRef(null);
  react.useLayoutEffect(() => {
    if (!fullViewportHeight) {
      if (nodeRef.current) {
        nodeRef.current.style.removeProperty('height');
        nodeRef.current.style.removeProperty('--vh');
      }
      return;
    }
    function updateHeight() {
      if (nodeRef.current) {
        // https://css-tricks.com/the-trick-to-viewport-units-on-mobile/
        nodeRef.current.style.setProperty('height', 'calc(var(--vh, 1vh) * 100)');
        nodeRef.current.style.setProperty('--vh', "".concat(window.innerHeight * 0.01, "px"));
      }
    }
    updateHeight();
    window.addEventListener('resize', updateHeight);
    return () => {
      window.removeEventListener('resize', updateHeight);
    };
  }, [fullViewportHeight]);
  return /*#__PURE__*/jsxRuntime.jsx("div", _objectSpread({
    ref: ui.mergeRefs(ref, nodeRef)
  }, props));
});
if (process.env.NODE_ENV !== "production") Container.displayName = "Container";
Container.displayName = 'Container';

function mergeStyles(styles) {
  for (var _len = arguments.length, sources = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    sources[_key - 1] = arguments[_key];
  }
  for (var source of sources) {
    if (source) {
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          var stylesValue = styles[key];
          var sourceValue = source[key];
          if (typeof stylesValue == 'object' && typeof sourceValue == 'object') {
            mergeStyles(stylesValue, sourceValue);
          } else {
            styles[key] = source[key];
          }
        }
      }
    }
  }
  return styles;
}

var _excluded$4 = ["variant", "as", "align", "color", "display", "noWrap", "wrapOverflow"];
var normalizeTextColor = /*#__PURE__*/createRuleNormalizer({
  inherit: 'inherit',
  primary: ui.ColorDynamic.Dark500,
  secondary: ui.ColorDynamic.Dark300,
  'light-gray': ui.ColorDynamic.Dark100,
  //*deprecated use disabled instead
  disabled: ui.ColorDynamic.Dark100,
  white: ui.ColorDynamic.White,
  blue: ui.ColorDynamic.Blue500,
  green: ui.ColorDynamic.Green500,
  purple: ui.ColorDynamic.Purple500,
  red: ui.ColorDynamic.Red500,
  teal: ui.ColorDynamic.Teal500,
  yellow: ui.ColorDynamic.Yellow500
});
var VARIANT_TYPE_MAPPING = {
  'heading-1': 'h1',
  'heading-2': 'h2',
  'heading-3': 'h3',
  'heading-4': 'h4',
  'heading-5': 'h5',
  'heading-6': 'h6',
  body: 'span',
  'body-block': 'p',
  'body-semibold': 'span',
  caption: 'span',
  hint: 'span'
};
function variantMixin(_ref, variant) {
  var {
    typography,
    breakpoints
  } = _ref;
  switch (variant) {
    case 'heading-1':
      return typography.h1;
    case 'heading-2':
      return typography.h2;
    case 'heading-3':
      return typography.h3;
    case 'heading-4':
      return typography.h4;
    case 'heading-5':
      return typography.h5;
    case 'heading-6':
      return typography.h6;
    case 'body':
    default:
      return typography.body2;
    case 'body-block':
      {
        return mergeStyles({}, typography.body2, {
          lineHeight: '24px',
          [breakpoints.only('xs')]: {
            lineHeight: '28px'
          }
        });
      }
    case 'body-semibold':
      return typography.body1;
    case 'caption':
      return typography.caption;
    case 'hint':
      return mergeStyles({}, typography.caption, {
        lineHeight: '20px',
        fontSize: '13px'
      });
  }
}
function textBoxMixin(noWrap, align, color, display, wrapOverflow) {
  return styled.css(["text-align:", ";color:", ";display:", ";overflow:", ";white-space:", ";overflow-wrap:", ";"], align, normalizeTextColor(color), display === 'initial' && (noWrap || align !== 'left') ? 'block' : display, noWrap ? 'hidden' : 'visible', noWrap ? 'nowrap' : 'normal', wrapOverflow ? 'break-word' : 'normal');
}
var TextBoxRoot = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "TextBox__TextBoxRoot",
  componentId: "SD__sc-9mywck-0"
})(_ref2 => {
  var {
    theme,
    $noWrap,
    $variant,
    $align,
    $color,
    $display,
    $wrapOverflow
  } = _ref2;
  return styled.css(["margin:0;padding:0;text-overflow:ellipsis;", ";", ";", "{", ";}", "{", ";}"], variantMixin(theme, $variant), textBoxMixin($noWrap[0], $align[0], $color[0], $display[0], $wrapOverflow[0]), theme.breakpoints.up('sm'), textBoxMixin($noWrap[1], $align[1], $color[1], $display[1], $wrapOverflow[1]), theme.breakpoints.up('md'), textBoxMixin($noWrap[2], $align[2], $color[2], $display[2], $wrapOverflow[2]));
});
var TextBox = /*#__PURE__*/react.forwardRef((_ref3, ref) => {
  var {
      variant: $variant = 'body',
      as = VARIANT_TYPE_MAPPING[$variant],
      align = 'left',
      color = 'primary',
      display = 'initial',
      noWrap = false,
      wrapOverflow = false
    } = _ref3,
    props = _objectWithoutProperties(_ref3, _excluded$4);
  var $align = ui.parseResponsiveProp(align);
  var $color = ui.parseResponsiveProp(color);
  var $noWrap = ui.parseResponsiveProp(noWrap);
  var $display = ui.parseResponsiveProp(display);
  var $wrapOverflow = ui.parseResponsiveProp(wrapOverflow);
  return /*#__PURE__*/jsxRuntime.jsx(TextBoxRoot, _objectSpread(_objectSpread({}, props), {}, {
    as: as,
    ref: ref,
    $align: $align,
    $color: $color,
    $noWrap: $noWrap,
    $display: $display,
    $variant: $variant,
    $wrapOverflow: $wrapOverflow
  }));
});
if (process.env.NODE_ENV !== "production") TextBox.displayName = "TextBox";

function descriptionItemIconMixin(size) {
  return styled.css(["width:", "px;height:", "px;& > .MuiSvgIcon-root{font-size:", "px;}"], size, size + 4, size);
}
var DescriptionItemIcon = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "DescriptionItem__DescriptionItemIcon",
  componentId: "SD__sc-1906hic-0"
})(_ref => {
  var {
    theme
  } = _ref;
  return styled.css(["display:flex;align-items:center;& > .MuiSvgIcon-root{color:", ";}", ";", "{", ";}"], ui.ColorDynamic.Dark100, descriptionItemIconMixin(20), theme.breakpoints.up('sm'), descriptionItemIconMixin(16));
});
var DescriptionItem = /*#__PURE__*/react.forwardRef((_ref2, ref) => {
  var {
    icon,
    wrap,
    inset,
    label,
    children,
    fallback,
    id: idProp,
    'aria-label': ariaLabel
  } = _ref2;
  var id = ui.useUID(idProp);
  var labelID = "".concat(id, "-label");
  var isEmptyChildren = ui.isEmptyReactNode(children);
  return /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
    id: id,
    ref: ref,
    space: "xsmall",
    "aria-label": ariaLabel,
    children: [!!(icon || inset) && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      width: "content",
      children: /*#__PURE__*/jsxRuntime.jsx(DescriptionItemIcon, {
        children: icon
      })
    }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      width: "adaptive",
      children: /*#__PURE__*/jsxRuntime.jsxs(ui.Inline, {
        space: "xxsmall",
        noWrap: !wrap,
        children: [!!label && /*#__PURE__*/jsxRuntime.jsx(TextBox, {
          as: "label",
          id: labelID,
          color: "secondary",
          children: label
        }), /*#__PURE__*/jsxRuntime.jsx(TextBox, {
          as: "div",
          noWrap: !wrap,
          wrapOverflow: !!wrap,
          "aria-labelledby": label == null ? undefined : labelID,
          color: isEmptyChildren && label == null ? 'secondary' : 'primary',
          children: isEmptyChildren ? fallback : children
        })]
      })
    })]
  });
});
if (process.env.NODE_ENV !== "production") DescriptionItem.displayName = "DescriptionItem";

var DottedLine = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "DescriptionLineItem__DottedLine",
  componentId: "SD__sc-1ixx5h8-0"
})(["border-bottom:1px dotted ", ";margin:0px 8px;height:7px;"], ui.ColorDynamic.Silver400);
var DescriptionLineItem = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    title,
    children
  } = _ref;
  return /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
    ref: ref,
    align: "center",
    children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      width: "content",
      children: title
    }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      width: "fluid",
      children: /*#__PURE__*/jsxRuntime.jsx(DottedLine, {})
    }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      width: "content",
      children: children
    })]
  });
});
if (process.env.NODE_ENV !== "production") DescriptionLineItem.displayName = "DescriptionLineItem";
DescriptionLineItem.displayName = 'DescriptionLineItem';

var _excluded$5 = ["disabled", "children", "hintText", "startIcon", "fallback", "accept", "maxSize", "maxFiles", "onDropRejected", "onDropAccepted"];
function toBytes(input, unit) {
  if (unit === 'gb') return input * (1 << 30);
  if (unit === 'mb') return input * (1 << 20);
  return input * (1 << 10);
}
var KILOBYTE = 1024;
var BYTE_UNITS = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
function formatBytes(bytes) {
  if (bytes === 0) return '0 Bytes';
  var unitIndex = Math.floor(Math.log(bytes) / Math.log(KILOBYTE));
  var unit = BYTE_UNITS[unitIndex];
  return "".concat((bytes / Math.pow(KILOBYTE, unitIndex)).toFixed(2), " ").concat(unit);
}
var StyledCardButton = /*#__PURE__*/styled__default(ui.CardButton).withConfig({
  displayName: "FileDropZone__StyledCardButton",
  componentId: "SD__sc-5p1fk0-0"
})(_ref => {
  var {
    status
  } = _ref;
  return {
    backgroundColor: status === 'active' ? ui.ColorDynamic.Blue50 : undefined
  };
});
function UploadRejection(_ref2) {
  var {
    maxSize,
    rejection
  } = _ref2;
  var [error] = rejection.errors;
  if (!error) return null;
  return /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
    align: "center",
    children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      width: "content",
      children: /*#__PURE__*/jsxRuntime.jsx(icons.Error, {})
    }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      children: error.code === 'file-too-large' ? maxSize == null ? 'Attachment size is too large' : "Attachment size should be less than ".concat(formatBytes(maxSize)) : error.message
    })]
  });
}
var FileDropZone = /*#__PURE__*/react.forwardRef((props, ref) => {
  var {
      // CardButton
      disabled = false,
      children: _children = 'Upload Attachments',
      hintText = 'or Drag & Drop files',
      startIcon = /*#__PURE__*/jsxRuntime.jsx(core.SvgIcon, {
        children: /*#__PURE__*/jsxRuntime.jsx("path", {
          d: js.mdiUpload
        })
      }),
      fallback = /*#__PURE__*/jsxRuntime.jsx(ui.CardButton, {
        ref: ref,
        disabled: true,
        startIcon: /*#__PURE__*/jsxRuntime.jsx(core.CircularProgress, {
          size: "1em",
          color: "inherit"
        }),
        children: "Loading dependencies\u2026"
      }),
      // Dropzone
      accept,
      maxSize = Infinity,
      maxFiles = Infinity,
      onDropRejected: _onDropRejected,
      onDropAccepted: _onDropAccepted
    } = props,
    dropzoneProps = _objectWithoutProperties(props, _excluded$5);
  return /*#__PURE__*/jsxRuntime.jsx(react.Suspense, {
    fallback: fallback,
    children: /*#__PURE__*/jsxRuntime.jsx(Dropzone, _objectSpread(_objectSpread({}, dropzoneProps), {}, {
      accept: accept,
      maxSize: maxSize,
      maxFiles: maxFiles,
      disabled: disabled,
      onDropAccepted: files => {
        _onDropAccepted === null || _onDropAccepted === void 0 ? void 0 : _onDropAccepted(files);
      },
      onDropRejected: fileRejections => {
        _onDropRejected === null || _onDropRejected === void 0 ? void 0 : _onDropRejected(fileRejections);
      },
      children: _ref3 => {
        var {
          isDragActive,
          isDragReject,
          getRootProps,
          getInputProps,
          fileRejections: [fileRejection]
        } = _ref3;
        return /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
          children: [/*#__PURE__*/jsxRuntime.jsx("input", _objectSpread({}, getInputProps())), /*#__PURE__*/jsxRuntime.jsx(StyledCardButton, _objectSpread(_objectSpread({}, getRootProps()), {}, {
            ref: ref,
            hint: hintText,
            disabled: disabled,
            startIcon: startIcon,
            status: isDragActive ? 'active' : isDragReject ? 'error' : 'idle',
            error: !!fileRejection && /*#__PURE__*/jsxRuntime.jsx(UploadRejection, {
              accept: accept,
              maxSize: maxSize,
              rejection: fileRejection
            }),
            children: _children
          }))]
        });
      }
    }))
  });
});
if (process.env.NODE_ENV !== "production") FileDropZone.displayName = "FileDropZone";

var FileListItemName = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FileListItem__FileListItemName",
  componentId: "SD__sc-hxbsiy-0"
})(["overflow:hidden;line-height:22px;white-space:nowrap;text-overflow:ellipsis;"]);
var FileListItemProgress = /*#__PURE__*/styled__default(core.CircularProgress).withConfig({
  displayName: "FileListItem__FileListItemProgress",
  componentId: "SD__sc-hxbsiy-1"
})(["font-size:24px;", "{font-size:14px;}"], _ref => {
  var {
    theme
  } = _ref;
  return theme.breakpoints.up('sm');
});
var PdfIcon = /*#__PURE__*/react.memo(props => /*#__PURE__*/jsxRuntime.jsx(core.SvgIcon, _objectSpread(_objectSpread({}, props), {}, {
  children: /*#__PURE__*/jsxRuntime.jsx("path", {
    d: js.mdiFilePdfBox
  })
})));
var TextBoxIcon = /*#__PURE__*/react.memo(props => /*#__PURE__*/jsxRuntime.jsx(core.SvgIcon, _objectSpread(_objectSpread({}, props), {}, {
  children: /*#__PURE__*/jsxRuntime.jsx("path", {
    d: js.mdiTextBox
  })
})));
var PDF_FILE_PATTERN = /\.pdf$/;
var IMAGE_FILE_PATTERN = /\.(gif|png|jpg|jpeg)$/;
function getFileType(name) {
  if (PDF_FILE_PATTERN.exec(name)) return 'pdf';
  if (IMAGE_FILE_PATTERN.exec(name)) return 'image';
  return 'unknown';
}
var FileListItem = /*#__PURE__*/react.forwardRef((_ref2, ref) => {
  var {
    url,
    name,
    status,
    canDelete = true,
    onRetry,
    onDelete
  } = _ref2;
  var uid = ui.useUID();
  var fileType = getFileType(name);
  var [isHoveredState, setIsHovered] = react.useState(false);
  var isHovered = ui.useResponsiveValue(true, isHoveredState);
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    ref: ref,
    onMouseOver: () => {
      setIsHovered(true);
    },
    onMouseLeave: () => {
      setIsHovered(false);
    },
    "aria-label": "file-list-item",
    children: /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
      align: "center",
      space: "xsmall",
      children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
        width: "content",
        children: status === 'error' ? /*#__PURE__*/jsxRuntime.jsx(icons.Error, {
          color: "error",
          fontSize: "small"
        }) : fileType === 'pdf' ? /*#__PURE__*/jsxRuntime.jsx(PdfIcon, {
          color: "action",
          fontSize: "small"
        }) : fileType === 'image' ? /*#__PURE__*/jsxRuntime.jsx(icons.Image, {
          color: "action",
          fontSize: "small"
        }) : /*#__PURE__*/jsxRuntime.jsx(TextBoxIcon, {
          color: "action",
          fontSize: "small"
        })
      }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
        width: "fluid",
        children: /*#__PURE__*/jsxRuntime.jsx(FileListItemName, {
          id: uid,
          children: !url ? name : /*#__PURE__*/jsxRuntime.jsx(core.Link, {
            href: url,
            noWrap: true,
            target: "_blank",
            rel: "noopener noreferrer",
            children: name
          })
        })
      }), status === 'error' && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
        width: "content",
        children: /*#__PURE__*/jsxRuntime.jsx(core.Tooltip, {
          title: "Retry",
          children: /*#__PURE__*/jsxRuntime.jsx(core.IconButton, {
            size: "small",
            onClick: onRetry,
            children: /*#__PURE__*/jsxRuntime.jsx(icons.Refresh, {
              fontSize: "small"
            })
          })
        })
      }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
        width: "content",
        children: status === 'loading' ? /*#__PURE__*/jsxRuntime.jsx(core.IconButton, {
          size: "small",
          disabled: true,
          children: /*#__PURE__*/jsxRuntime.jsx(FileListItemProgress, {
            size: "1em"
          })
        }) : !isHovered && status === 'success' ? /*#__PURE__*/jsxRuntime.jsx(core.IconButton, {
          size: "small",
          children: /*#__PURE__*/jsxRuntime.jsx(icons.CheckCircle, {
            fontSize: "small",
            htmlColor: ui.ColorDynamic.Green300
          })
        }) : canDelete ? /*#__PURE__*/jsxRuntime.jsx(core.Tooltip, {
          title: "Delete",
          children: /*#__PURE__*/jsxRuntime.jsx(core.IconButton, {
            size: "small",
            onClick: onDelete,
            children: /*#__PURE__*/jsxRuntime.jsx(icons.Delete, {
              fontSize: "small"
            })
          })
        }) : null
      })]
    })
  });
});
if (process.env.NODE_ENV !== "production") FileListItem.displayName = "FileListItem";

var FlagListHeader = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FlagList__FlagListHeader",
  componentId: "SD__sc-te7hyy-0"
})(["display:flex;align-items:center;justify-content:space-between;flex-wrap:wrap;gap:16px;padding:12px 16px;background:", ";border:1px solid ", ";border-bottom:none;border-radius:4px 4px 0 0;", "{flex-direction:column;align-items:flex-start;}"], ui.ColorDynamic.Silver200, ui.ColorDynamic.Silver400, _ref => {
  var {
    theme
  } = _ref;
  return theme.breakpoints.down('xs');
});
var FlagListContainer = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FlagList__FlagListContainer",
  componentId: "SD__sc-te7hyy-1"
})(["display:flex;flex-direction:column;"]);
var FlagList = /*#__PURE__*/react.forwardRef((_ref2, ref) => {
  var {
    isStandalone = false,
    title,
    endAction,
    children
  } = _ref2;
  return /*#__PURE__*/jsxRuntime.jsxs(FlagListContainer, {
    "data-variant": isStandalone ? 'standalone' : 'with-header',
    ref: ref,
    children: [(title || endAction) && /*#__PURE__*/jsxRuntime.jsxs(FlagListHeader, {
      children: [title, endAction]
    }), children]
  });
});
if (process.env.NODE_ENV !== "production") FlagList.displayName = "FlagList";

var _excluded$6 = ["variant", "showHelpIcon", "endAction", "children"];
var IconContainer = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FlagListItem__IconContainer",
  componentId: "SD__sc-o5bqru-0"
})(["padding:4px;border-radius:50%;background:", ";color:", ";transition:", ";& .MuiSvgIcon-root{font-size:16px;}"], ui.ColorDynamic.Silver200, ui.ColorDynamic.Blue300, _ref => {
  var {
    theme
  } = _ref;
  return theme.transitions.create(['color', 'background-color']);
});
var Content = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FlagListItem__Content",
  componentId: "SD__sc-o5bqru-1"
})(["display:flex;align-items:center;width:100%;gap:8px;"]);
var HelpIcon = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FlagListItem__HelpIcon",
  componentId: "SD__sc-o5bqru-2"
})(["margin-left:auto;& > svg{font-size:16px;color:", ";}"], ui.ColorDynamic.Dark500);
var EndActions = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FlagListItem__EndActions",
  componentId: "SD__sc-o5bqru-3"
})(["display:flex;align-items:center;margin-left:auto;gap:8px;", "{margin-left:0;width:100%;}"], _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.breakpoints.down('xs');
});
var BannerListItemDanger = /*#__PURE__*/styled.css(["& ", "{background:", ";color:", ";}&:hover{background:", ";}"], IconContainer, ui.ColorDynamic.Red50, ui.ColorDynamic.Red300, ui.ColorDynamic.Red50);
var BannerListItemStandalone = /*#__PURE__*/styled.css(["background:", ";"], ui.ColorDynamic.Silver200);
var BannerListContainer = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "FlagListItem__BannerListContainer",
  componentId: "SD__sc-o5bqru-4"
})(["display:flex;align-items:center;gap:8px;padding:8px 16px 8px 12px;border:1px solid ", ";background:", ";cursor:default;transition:", ";& + &{border-top:none;}&:last-child{border-radius:0 0 4px 4px;}&:hover{background:", ";& ", "{background:", ";}& ", " > svg{color:", ";}}[data-variant='standalone'] &:not(:hover){", "}", " ", "{flex-direction:column;align-items:flex-start;}"], ui.ColorDynamic.Silver400, ui.ColorDynamic.White, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.transitions.create(['color', 'background-color']);
}, ui.ColorDynamic.Blue50, IconContainer, ui.ColorDynamic.White, HelpIcon, _ref4 => {
  var {
    $variant
  } = _ref4;
  return $variant === 'danger' ? ui.ColorDynamic.Red300 : ui.ColorDynamic.Blue300;
}, BannerListItemStandalone, _ref5 => {
  var {
    $variant
  } = _ref5;
  return $variant === 'danger' ? BannerListItemDanger : null;
}, _ref6 => {
  var {
    theme
  } = _ref6;
  return theme.breakpoints.down('xs');
});
var FlagListItem = /*#__PURE__*/react.forwardRef((_ref7, ref) => {
  var {
      variant = 'primary',
      showHelpIcon,
      endAction,
      children
    } = _ref7,
    rest = _objectWithoutProperties(_ref7, _excluded$6);
  return /*#__PURE__*/jsxRuntime.jsxs(BannerListContainer, _objectSpread(_objectSpread({}, rest), {}, {
    ref: ref,
    $variant: variant,
    children: [/*#__PURE__*/jsxRuntime.jsxs(Content, {
      children: [/*#__PURE__*/jsxRuntime.jsx(IconContainer, {
        children: variant === 'danger' ? /*#__PURE__*/jsxRuntime.jsx(icons.Error, {}) : variant === 'warning' ? /*#__PURE__*/jsxRuntime.jsx(icons.Warning, {}) : /*#__PURE__*/jsxRuntime.jsx(icons.Flag, {})
      }), children, /*#__PURE__*/jsxRuntime.jsx(HelpIcon, {
        children: showHelpIcon && /*#__PURE__*/jsxRuntime.jsx(icons.Help, {})
      })]
    }), endAction && /*#__PURE__*/jsxRuntime.jsx(EndActions, {
      children: endAction
    })]
  }));
});
if (process.env.NODE_ENV !== "production") FlagListItem.displayName = "FlagListItem";

var _excluded$7 = ["color", "target", "rel"],
  _excluded2$2 = ["children", "linkComponent"];
var DefaultLinkComponent = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
      color,
      target = '_blank',
      rel = 'noreferrer noopener'
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded$7);
  return /*#__PURE__*/jsxRuntime.jsx(core.Link, _objectSpread(_objectSpread({}, props), {}, {
    ref: ref,
    rel: rel,
    target: target
  }));
});
if (process.env.NODE_ENV !== "production") DefaultLinkComponent.displayName = "DefaultLinkComponent";
DefaultLinkComponent.displayName = 'DefaultLinkComponent';
function LinkedText(_ref2) {
  var {
      children,
      linkComponent = DefaultLinkComponent
    } = _ref2,
    props = _objectWithoutProperties(_ref2, _excluded2$2);
  if (!children) {
    return null;
  }
  return /*#__PURE__*/jsxRuntime.jsx(reactAnchorme.Anchorme, _objectSpread(_objectSpread({}, props), {}, {
    linkComponent: linkComponent,
    children: children
  }));
}

var MultilineText = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "MultilineText",
  componentId: "SD__sc-34heyp-0"
})(["white-space:pre-wrap;overflow-wrap:", ";"], _ref => {
  var {
    overflowWrap = 'normal'
  } = _ref;
  return overflowWrap;
});
MultilineText.displayName = 'MultilineText';

var NavbarContext = /*#__PURE__*/react.createContext({
  isDrawerOpen: false,
  isMenuExpanded: false,
  isNavbarExpanded: false,
  setMenuExpanded: lodash.noop,
  setDrawerOpen: lodash.noop
});
function useNavbarContext() {
  return react.useContext(NavbarContext);
}

var _excluded$8 = ["active", "hasBadge"];
var StyledBottomNavigation = /*#__PURE__*/styled__default(core.BottomNavigation).withConfig({
  displayName: "NavbarBottomBar__StyledBottomNavigation",
  componentId: "SD__sc-9z6v3k-0"
})(["background:", ";"], ui.ColorDynamic.Dark500);
var StyledBottomNavigationAction = /*#__PURE__*/styled__default(core.BottomNavigationAction).withConfig({
  displayName: "NavbarBottomBar__StyledBottomNavigationAction",
  componentId: "SD__sc-9z6v3k-1"
})(["&&{background:#1b2638;color:", ";padding:6px 0 8px;line-height:20px;}&:first-child{padding-left:12px;}&:last-child{padding-right:12px;}&.Mui-selected{color:", ";.MuiBottomNavigationAction-label{font-size:0.75rem;}}"], ui.ColorDynamic.Silver500, ui.ColorDynamic.White);
var IconWrapper = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarBottomBar__IconWrapper",
  componentId: "SD__sc-9z6v3k-2"
})(["position:relative;"]);
var IconLabel = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarBottomBar__IconLabel",
  componentId: "SD__sc-9z6v3k-3"
})(["display:flex;align-items:center;justify-content:center;font-size:12px;border-radius:50%;color:", ";background:", ";position:absolute;top:0;right:0;width:8px;height:8px;"], ui.ColorDynamic.White, ui.ColorDynamic.Red300);
function NavbarBottomBar(_ref) {
  var {
    items,
    hasMenuBadge
  } = _ref;
  var {
    isDrawerOpen,
    setDrawerOpen
  } = useNavbarContext();
  var activeItem = react.useMemo(() => items.find(item => item.active), [items]);
  return /*#__PURE__*/jsxRuntime.jsxs(StyledBottomNavigation, {
    value: activeItem === null || activeItem === void 0 ? void 0 : activeItem.value,
    showLabels: true,
    onChange: (_event, newValue) => {
      if (newValue) {
        if (newValue === 'menu') {
          setDrawerOpen(!isDrawerOpen);
        } else {
          setDrawerOpen(false);
        }
      }
    },
    children: [items.map(_ref2 => {
      var {
          active,
          hasBadge
        } = _ref2,
        item = _objectWithoutProperties(_ref2, _excluded$8);
      return /*#__PURE__*/react.createElement(StyledBottomNavigationAction, _objectSpread(_objectSpread({}, item), {}, {
        key: item.value,
        icon: hasBadge ? /*#__PURE__*/jsxRuntime.jsxs(IconWrapper, {
          children: [/*#__PURE__*/jsxRuntime.jsx(IconLabel, {}), item.icon]
        }) : item.icon
      }));
    }), /*#__PURE__*/jsxRuntime.jsx(StyledBottomNavigationAction, {
      value: "menu",
      label: "Menu",
      icon: hasMenuBadge ? /*#__PURE__*/jsxRuntime.jsxs(IconWrapper, {
        children: [/*#__PURE__*/jsxRuntime.jsx(IconLabel, {}), /*#__PURE__*/jsxRuntime.jsx(icons.Menu, {
          fontSize: "small"
        })]
      }) : /*#__PURE__*/jsxRuntime.jsx(icons.Menu, {
        fontSize: "small"
      })
    })]
  });
}

var NavbarBadge = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "NavbarItem__NavbarBadge",
  componentId: "SD__sc-1pvzq3w-0"
})(["flex-shrink:0;padding:4px 6px;min-width:20px;line-height:12px;font-size:12px;font-weight:400;border-radius:10px;text-align:center;background:", ";&[data-variant='primary']{color:", ";background:", ";}&[data-variant='danger']{color:", ";background:", ";}"], /*#__PURE__*/core.alpha(ui.Color.White, 0.05), ui.Color.White, ui.ColorDynamic.Blue300, ui.Color.White, ui.ColorDynamic.Red300);
var NavbarLabel = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "NavbarItem__NavbarLabel",
  componentId: "SD__sc-1pvzq3w-1"
})(["flex-grow:1;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;"]);
var NavbarItemRoot = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarItem__NavbarItemRoot",
  componentId: "SD__sc-1pvzq3w-2"
})(["width:100%;display:flex;align-items:center;color:#c2c4c9;font-size:14px;font-weight:400;line-height:20px;text-decoration:none;outline:none;cursor:pointer;padding:8px 16px;border-left:4px solid transparent;&[aria-current],&[data-active='true']{color:", ";background-color:", ";border-left-color:", ";}&:hover{background-color:", ";color:", ";border-left-color:", ";}"], ui.Color.White, ui.Color.White10, ui.ColorDynamic.Blue300, ui.Color.White08, ui.Color.White, ui.ColorDynamic.Blue300);
var IconWrapper$1 = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarItem__IconWrapper",
  componentId: "SD__sc-1pvzq3w-3"
})(["width:24px;margin-right:8px;& svg{font-size:24px;}"]);
function NavbarItem(_ref) {
  var {
    label,
    gutter,
    badge,
    icon,
    component,
    onClick,
    variant,
    ident = 0,
    active
  } = _ref;
  var uid = ui.useUID();
  return /*#__PURE__*/jsxRuntime.jsxs(NavbarItemRoot, {
    as: component,
    onClick: onClick,
    "aria-labelledby": uid,
    "data-active": active,
    style: {
      marginTop: gutter ? '16px' : '0',
      paddingLeft: (ident + 1) * 20
    },
    children: [/*#__PURE__*/jsxRuntime.jsx(IconWrapper$1, {
      children: icon
    }), /*#__PURE__*/jsxRuntime.jsx(NavbarLabel, {
      id: uid,
      children: label
    }), badge != null && /*#__PURE__*/jsxRuntime.jsx(NavbarBadge, {
      "data-variant": variant,
      children: badge
    })]
  });
}

var NavbarAccordionLabel = /*#__PURE__*/styled__default.span.withConfig({
  displayName: "NavbarAccordion__NavbarAccordionLabel",
  componentId: "SD__sc-1s7g3kw-0"
})(["flex-grow:1;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;&[data-expanded='false']{display:none;}"]);
var NavbarAccordionRoot = /*#__PURE__*/styled__default(core.Accordion).withConfig({
  displayName: "NavbarAccordion__NavbarAccordionRoot",
  componentId: "SD__sc-1s7g3kw-1"
})(["width:100%;color:#c2c4c9;font-size:14px;font-weight:400;line-height:20px;text-decoration:none;outline:none;cursor:pointer;background-color:", ";&[aria-current]{background-color:", ";color:", ";}&.MuiAccordion-root:before{background-color:#1b2638;}&.MuiPaper-elevation0{border:0px;}&[data-gutter]{margin-top:16px;}&[data-gutter].MuiAccordion-root.Mui-expanded{margin-top:16px;}"], _ref => {
  var {
    theme
  } = _ref;
  return theme.palette.type === 'dark' ? ui.ColorDark.White : ui.Color.Dark500;
}, ui.Color.White10, ui.ColorDynamic.White);
var NavbarAccordionSummary = /*#__PURE__*/styled__default(core.AccordionSummary).withConfig({
  displayName: "NavbarAccordion__NavbarAccordionSummary",
  componentId: "SD__sc-1s7g3kw-2"
})(["border-left:4px solid transparent;padding-left:20px;&.MuiAccordionSummary-root{max-height:40px;min-height:40px;}&.MuiAccordionSummary-content{align-items:center;}&:hover,&[aria-current],&[data-active='true']{color:", ";background-color:", ";border-left-color:", ";}&[data-expanded='false']{.MuiAccordionSummary-expandIcon{display:none;}}"], ui.Color.White, ui.Color.White10, ui.ColorDynamic.Blue300);
var IconWrapper$2 = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarAccordion__IconWrapper",
  componentId: "SD__sc-1s7g3kw-3"
})(["width:24px;margin-right:8px;& svg{font-size:24px;}"]);
function NavbarAccordion(_ref2) {
  var {
    label,
    icon,
    gutter,
    items,
    onClick: _onClick
  } = _ref2;
  var uid = ui.useUID();
  var {
    setDrawerOpen,
    isNavbarExpanded
  } = useNavbarContext();
  var [isExpanded, setExpanded] = react.useState(true);

  // sync accordion state with Desktop menu state
  react.useEffect(() => {
    setExpanded(isNavbarExpanded);
  }, [isNavbarExpanded]);
  var filteredItems = react.useMemo(() => items.filter(item => !item.hide), [items]);
  return /*#__PURE__*/jsxRuntime.jsxs(NavbarAccordionRoot, {
    square: true,
    "data-gutter": !gutter,
    "aria-labelledby": uid,
    expanded: isExpanded,
    onClick: event => {
      _onClick === null || _onClick === void 0 ? void 0 : _onClick(event);
      if (isNavbarExpanded) {
        setExpanded(!isExpanded);
      }
    },
    children: [/*#__PURE__*/jsxRuntime.jsxs(NavbarAccordionSummary, {
      "data-active": !isExpanded && items.some(item => item.active),
      "data-expanded": isNavbarExpanded,
      expandIcon: /*#__PURE__*/jsxRuntime.jsx(icons.ExpandMore, {}),
      children: [/*#__PURE__*/jsxRuntime.jsx(IconWrapper$2, {
        children: icon
      }), /*#__PURE__*/jsxRuntime.jsx(NavbarAccordionLabel, {
        id: uid,
        "data-expanded": isNavbarExpanded,
        children: label
      })]
    }), filteredItems.map(item => {
      var index = filteredItems.indexOf(item);
      var prev = filteredItems[index - 1];
      var {
        ident = 0
      } = item;
      return /*#__PURE__*/react.createElement(NavbarItem, _objectSpread(_objectSpread({}, item), {}, {
        key: item.key,
        ident: ident,
        active: item.active,
        gutter: prev && prev.groupKey !== item.groupKey,
        onClick: event => {
          var _item$onClick;
          event.stopPropagation();
          (_item$onClick = item.onClick) === null || _item$onClick === void 0 ? void 0 : _item$onClick.call(item, event);
          if (!event.isDefaultPrevented()) {
            setDrawerOpen(false);
          }
        }
      }));
    })]
  });
}

var Header = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarList__Header",
  componentId: "SD__sc-19zrmxc-0"
})(["margin:0 16px 8px;display:flex;flex-shrink:0;align-items:center;justify-content:space-between;position:sticky;"]);
var Wrapper = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarList__Wrapper",
  componentId: "SD__sc-19zrmxc-1"
})(["display:flex;flex:1;flex-direction:column;overflow:hidden;padding-top:16px;background:", ";transition:width 0.3s linear;height:100%;width:", ";&[data-expanded='true']{width:", ";}&[data-expanded='false']{width:", ";& > ", "{justify-content:center;}}"], _ref => {
  var {
    theme
  } = _ref;
  return theme.palette.type === 'dark' ? ui.ColorDark.White : ui.Color.Dark500;
}, _ref2 => {
  var {
    isMobile
  } = _ref2;
  return isMobile ? '280px' : 'initial';
}, _ref3 => {
  var {
    isMobile
  } = _ref3;
  return isMobile ? '280px' : '240px';
}, _ref4 => {
  var {
    isMobile
  } = _ref4;
  return isMobile ? '280px' : '72px';
}, Header);
var ExpandIconButton = /*#__PURE__*/styled__default(core.IconButton).withConfig({
  displayName: "NavbarList__ExpandIconButton",
  componentId: "SD__sc-19zrmxc-2"
})(["color:", ";&&:focus{background-color:inherit;}"], ui.ColorDynamic.Dark100);
var Footer = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarList__Footer",
  componentId: "SD__sc-19zrmxc-3"
})(["flex-grow:1;display:flex;align-items:flex-end;margin:16px 0 8px;position:sticky;"]);
var Root = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarList__Root",
  componentId: "SD__sc-19zrmxc-4"
})(["color:inherit;background-color:unset;border-left:unset;font-size:14px;font-weight:400;line-height:20px;text-decoration:none;padding:8px 16px;svg{font-size:24px;color:", ";}"], ui.ColorDynamic.Dark100);
function NavbarMenuItem(_ref5) {
  var {
    label,
    icon,
    onClick,
    component
  } = _ref5;
  return /*#__PURE__*/jsxRuntime.jsx(Root, {
    as: component,
    onClick: onClick,
    children: /*#__PURE__*/jsxRuntime.jsxs(ui.Inline, {
      space: "xsmall",
      verticalAlign: "center",
      children: [icon, /*#__PURE__*/jsxRuntime.jsx(NavbarLabel, {
        children: label
      })]
    })
  });
}
var Content$1 = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarList__Content",
  componentId: "SD__sc-19zrmxc-5"
})(["height:100%;min-height:50px;overflow-y:auto;overflow-x:hidden;&[aria-expanded='false']{", ",", "{display:none;}}&::-webkit-scrollbar{width:10px;height:10px;}&::-webkit-scrollbar-track{background-color:transparent;}&::-webkit-scrollbar-thumb{background-color:", ";border-radius:100vw;margin-bottom:100px;}"], NavbarBadge, NavbarLabel, ui.ColorDark.Silver500);
function NavbarList(_ref6) {
  var {
    header,
    items,
    footer
  } = _ref6;
  var platform = ui.useResponsiveValue('mobile', 'tablet', 'desktop');
  var isMobile = platform === 'mobile';
  var {
    isMenuExpanded,
    isDrawerOpen,
    setDrawerOpen,
    setMenuExpanded
  } = useNavbarContext();
  var isSidebarOpened = isMobile ? isDrawerOpen : isMenuExpanded;
  var filteredItems = react.useMemo(() => items.filter(item => {
    return !item.hide && (isSidebarOpened || !!item.icon);
  }).map(item => _objectSpread(_objectSpread({}, item), {}, {
    menuGroupKey: item.groupKey
  })), [items, isSidebarOpened]);
  return /*#__PURE__*/jsxRuntime.jsxs(Wrapper, {
    isMobile: isMobile,
    "data-expanded": isSidebarOpened,
    children: [/*#__PURE__*/jsxRuntime.jsxs(Header, {
      children: [isSidebarOpened && header, !isMobile && /*#__PURE__*/jsxRuntime.jsx(ExpandIconButton, {
        disableRipple: true,
        style: isMenuExpanded ? {
          paddingRight: 0
        } : {},
        onClick: () => {
          setMenuExpanded(!isMenuExpanded);
        },
        children: isMenuExpanded ? /*#__PURE__*/jsxRuntime.jsx(icons.MenuOpen, {}) : /*#__PURE__*/jsxRuntime.jsx(icons.Menu, {})
      })]
    }), /*#__PURE__*/jsxRuntime.jsx(Content$1, {
      "aria-expanded": isSidebarOpened,
      children: filteredItems.map(item => {
        var index = filteredItems.indexOf(item);
        var prev = filteredItems[index - 1];
        if ('items' in item) {
          return /*#__PURE__*/react.createElement(NavbarAccordion, _objectSpread(_objectSpread({}, item), {}, {
            key: item.key,
            gutter: prev && prev.groupKey !== item.groupKey,
            onClick: item.onClick
          }));
        }
        return /*#__PURE__*/react.createElement(NavbarItem, _objectSpread(_objectSpread({}, item), {}, {
          key: item.key,
          gutter: prev && prev.groupKey !== item.groupKey,
          onClick: event => {
            var _item$onClick;
            (_item$onClick = item.onClick) === null || _item$onClick === void 0 ? void 0 : _item$onClick.call(item, event);
            if (!event.isDefaultPrevented()) {
              setDrawerOpen(false);
            }
          }
        }));
      })
    }), /*#__PURE__*/jsxRuntime.jsx(Footer, {
      children: footer
    })]
  });
}

var Aside = /*#__PURE__*/styled__default.aside.withConfig({
  displayName: "Navbar__Aside",
  componentId: "SD__sc-1oiqig8-0"
})(["display:flex;flex-direction:column;overflow:auto;border-right:1px solid ", ";"], ui.ColorDynamic.Silver400);
var Main = /*#__PURE__*/styled__default.main.withConfig({
  displayName: "Navbar__Main",
  componentId: "SD__sc-1oiqig8-1"
})(["flex:1;display:flex;flex-direction:column;overflow:auto;"]);
function Navbar(_ref) {
  var {
    footer,
    items,
    header,
    bottomItems,
    children,
    containerStyle,
    hasExtraBadge
  } = _ref;
  var theme = core.useTheme();
  var [isDrawerOpen, setDrawerOpen] = react.useState(false);
  var platform = ui.useResponsiveValue('mobile', 'tablet', 'desktop');
  var isMobile = platform === 'mobile';
  var matches = core.useMediaQuery(theme.breakpoints.up('md'), {
    noSsr: true
  });
  var [isMenuExpanded, setMenuExpanded] = react.useState(matches);
  var hasBadge = hasExtraBadge || items.some(item => item.badge);
  var ctx = react.useMemo(() => ({
    isDrawerOpen,
    isMenuExpanded,
    setDrawerOpen,
    setMenuExpanded,
    isNavbarExpanded: isMenuExpanded || isDrawerOpen
  }), [isDrawerOpen, isMenuExpanded, setMenuExpanded, setDrawerOpen]);
  return /*#__PURE__*/jsxRuntime.jsx(NavbarContext.Provider, {
    value: ctx,
    children: /*#__PURE__*/jsxRuntime.jsxs("div", {
      style: _objectSpread({
        display: 'flex',
        height: '100%',
        flexDirection: isMobile ? 'column' : 'row'
      }, containerStyle),
      children: [!isMobile && /*#__PURE__*/jsxRuntime.jsx(Aside, {
        children: /*#__PURE__*/jsxRuntime.jsx(NavbarList, {
          header: header,
          items: items,
          footer: footer
        })
      }), /*#__PURE__*/jsxRuntime.jsx(Main, {
        children: children
      }), isMobile && /*#__PURE__*/jsxRuntime.jsx(NavbarBottomBar, {
        items: bottomItems,
        hasMenuBadge: hasBadge
      }), /*#__PURE__*/jsxRuntime.jsx(core.Drawer, {
        open: isDrawerOpen,
        anchor: "right",
        onClose: () => {
          setDrawerOpen(false);
        },
        PaperProps: {
          style: {
            width: '280px',
            minWidth: '280px'
          }
        },
        children: /*#__PURE__*/jsxRuntime.jsx(NavbarList, {
          header: header,
          items: items,
          footer: footer
        })
      })]
    })
  });
}

var _excluded$9 = ["title", "subtitle", "children"];
var StyledTypography = /*#__PURE__*/styled__default(core.Typography).withConfig({
  displayName: "NavbarAvatar__StyledTypography",
  componentId: "SD__sc-19q2zd0-0"
})(["color:", ";text-overflow:ellipsis;white-space:nowrap;overflow:hidden;&:hover{color:", ";}"], ui.Color.White, ui.Color.White);
function NavbarAvatar(_ref) {
  var {
      title,
      subtitle,
      children
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded$9);
  var {
    isNavbarExpanded
  } = useNavbarContext();
  if (!isNavbarExpanded) {
    return /*#__PURE__*/jsxRuntime.jsx(core.Avatar, _objectSpread(_objectSpread({}, props), {}, {
      children: children
    }));
  }
  return /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
    space: "xsmall",
    align: "center",
    children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      width: "content",
      children: /*#__PURE__*/jsxRuntime.jsx(core.Avatar, _objectSpread(_objectSpread({}, props), {}, {
        children: children
      }))
    }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
      children: /*#__PURE__*/jsxRuntime.jsxs(ui.Stack, {
        space: "none",
        children: [/*#__PURE__*/jsxRuntime.jsx(StyledTypography, {
          variant: "caption",
          children: title
        }), /*#__PURE__*/jsxRuntime.jsx(StyledTypography, {
          variant: "caption",
          children: subtitle
        })]
      })
    })]
  });
}

var Divider = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarMenu__Divider",
  componentId: "SD__sc-1c8icpt-0"
})(["border-bottom:1px solid ", ";margin:8px -16px;"], ui.ColorDynamic.Silver400);
var StyledMenuItem = /*#__PURE__*/styled__default(core.MenuItem).withConfig({
  displayName: "NavbarMenu__StyledMenuItem",
  componentId: "SD__sc-1c8icpt-1"
})(["& svg{font-size:24px;color:", ";}"], ui.ColorDynamic.Dark100);
var Wrapper$1 = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "NavbarMenu__Wrapper",
  componentId: "SD__sc-1c8icpt-2"
})(["width:100%;padding:8px 16px;cursor:pointer;background:", ";border-left:4px solid ", ";&:hover{border-left-color:", ";background:", ";}"], ui.Color.White10, _ref => {
  var {
    active
  } = _ref;
  return active ? ui.ColorDynamic.Blue300 : 'transparent';
}, ui.ColorDynamic.Blue300, ui.Color.White08);
function NavbarMenu(_ref2) {
  var {
    items,
    children
  } = _ref2;
  var {
    setDrawerOpen
  } = useNavbarContext();
  var [anchor, setAnchor] = react.useState(null);
  function showProfileMenu(event) {
    setAnchor(event.currentTarget);
  }
  function hideProfileMenu() {
    setAnchor(null);
    setDrawerOpen(false);
  }
  return /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
    children: [/*#__PURE__*/jsxRuntime.jsx(Wrapper$1, {
      onClick: showProfileMenu,
      active: !!anchor,
      children: children
    }), /*#__PURE__*/jsxRuntime.jsx(core.Menu, {
      open: !!anchor,
      anchorEl: anchor,
      onClose: hideProfileMenu,
      onClick: hideProfileMenu,
      anchorOrigin: {
        vertical: 'top',
        horizontal: 'center'
      },
      transformOrigin: {
        vertical: 'bottom',
        horizontal: 'center'
      },
      children: items.filter(item => item.visible !== false).flatMap((item, index, arr) => {
        return [/*#__PURE__*/jsxRuntime.jsx(StyledMenuItem, {
          onClick: item.onClick,
          children: /*#__PURE__*/jsxRuntime.jsxs(ui.Inline, {
            space: "small",
            verticalAlign: "center",
            children: [item.icon, /*#__PURE__*/jsxRuntime.jsx(core.Typography, {
              style: {
                color: ui.ColorDynamic.Dark500
              },
              children: item.label
            })]
          })
        }, item.key), index !== arr.length - 1 && /*#__PURE__*/jsxRuntime.jsx(Divider, {}, "".concat(item.key, "-divider"))];
      })
    })]
  });
}

var SidebarRoot = /*#__PURE__*/styled__default.aside.withConfig({
  displayName: "Sidebar__SidebarRoot",
  componentId: "SD__sc-b77o22-0"
})(["top:0;position:sticky;overflow-y:auto;overflow-x:hidden;height:100vh;background-color:", ";border-right:1px solid ", ";"], ui.ColorDynamic.White, ui.ColorDynamic.Silver400);
var SidebarHeader = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "Sidebar__SidebarHeader",
  componentId: "SD__sc-b77o22-1"
})(["top:0;z-index:2;position:sticky;padding-left:24px;padding-right:24px;padding-bottom:8px;background-color:", ";"], ui.ColorDynamic.White);
var SidebarTitle = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "Sidebar__SidebarTitle",
  componentId: "SD__sc-b77o22-2"
})(["height:64px;max-height:64px;display:flex;align-items:center;"]);
var Sidebar = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    title,
    count,
    header,
    children,
    id: idProp
  } = _ref;
  var id = ui.useUID(idProp);
  var titleID = "".concat(id, "-title");
  return /*#__PURE__*/jsxRuntime.jsxs(SidebarRoot, {
    id: id,
    ref: ref,
    children: [/*#__PURE__*/jsxRuntime.jsxs(SidebarHeader, {
      children: [title && /*#__PURE__*/jsxRuntime.jsx(SidebarTitle, {
        children: /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
          space: "xsmall",
          align: "center",
          children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
            width: "fluid",
            children: /*#__PURE__*/jsxRuntime.jsx(TextBox, {
              variant: "heading-2",
              noWrap: true,
              id: titleID,
              children: title
            })
          }), !!count && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
            width: "content",
            children: /*#__PURE__*/jsxRuntime.jsx(TextBox, {
              color: "secondary",
              children: count
            })
          })]
        })
      }), header]
    }), /*#__PURE__*/jsxRuntime.jsx("div", {
      "aria-labelledby": titleID,
      children: children
    })]
  });
});
if (process.env.NODE_ENV !== "production") Sidebar.displayName = "Sidebar";

var Context = /*#__PURE__*/react.createContext(null);
function useSidebarContext() {
  var context = react.useContext(Context);
  if (!context) {
    throw new Error('SidebarContext is used outside Provider');
  }
  return context;
}
var SidebarContainerSidebar = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarContainer__SidebarContainerSidebar",
  componentId: "SD__sc-uibj1m-0"
})(["height:inherit;max-height:inherit;min-height:inherit;width:240px;"]);
var SidebarContainerContent = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarContainer__SidebarContainerContent",
  componentId: "SD__sc-uibj1m-1"
})(["height:inherit;max-height:inherit;min-height:inherit;"]);
var SidebarContainerRoot = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarContainer__SidebarContainerRoot",
  componentId: "SD__sc-uibj1m-2"
})(["display:flex;height:inherit;max-height:inherit;min-height:inherit;& ", "{width:calc(100% - 240px);min-width:calc(100% - 240px);max-width:calc(100% - 240px);}&[data-visibility='sidebar'] ", "{width:100%;}&[data-visibility='sidebar'] ", "{display:none;}&[data-visibility='content'] ", "{display:none;}&[data-visibility='content'] ", "{width:100%;max-width:unset;}"], SidebarContainerContent, SidebarContainerSidebar, SidebarContainerContent, SidebarContainerSidebar, SidebarContainerContent);
var SidebarContainer = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    sidebar,
    children
  } = _ref;
  var isCollapsed = ui.useCollapseBreakpoint('sm');
  var [visibilityState, setVisibilityState] = react.useState('sidebar');
  var visibility = isCollapsed ? visibilityState : 'both';
  var context = react.useMemo(() => {
    return {
      openSidebar: () => {
        setVisibilityState('sidebar');
      },
      openSidebarContent: () => {
        setVisibilityState('content');
      }
    };
  }, []);
  return /*#__PURE__*/jsxRuntime.jsx(Context.Provider, {
    value: context,
    children: /*#__PURE__*/jsxRuntime.jsxs(SidebarContainerRoot, {
      ref: ref,
      "data-visibility": visibility,
      children: [/*#__PURE__*/jsxRuntime.jsx(SidebarContainerSidebar, {
        children: sidebar
      }), /*#__PURE__*/jsxRuntime.jsx(SidebarContainerContent, {
        children: children
      })]
    })
  });
});
if (process.env.NODE_ENV !== "production") SidebarContainer.displayName = "SidebarContainer";

var _excluded$a = ["onClick", "children"];
function SidebarBackButton(_ref) {
  var {
      onClick: _onClick,
      children = /*#__PURE__*/jsxRuntime.jsx(icons.ArrowBack, {
        fontSize: "small"
      })
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded$a);
  var isCollapsed = ui.useCollapseBreakpoint('sm');
  var {
    openSidebar
  } = useSidebarContext();
  if (!isCollapsed) {
    return null;
  }
  return /*#__PURE__*/jsxRuntime.jsx(core.IconButton, _objectSpread(_objectSpread({}, props), {}, {
    size: "small",
    onClick: event => {
      _onClick === null || _onClick === void 0 ? void 0 : _onClick(event);
      if (!event.isDefaultPrevented()) {
        openSidebar();
      }
    },
    children: children
  }));
}

var SidebarAppBar = /*#__PURE__*/styled__default(core.AppBar).withConfig({
  displayName: "SidebarContent__SidebarAppBar",
  componentId: "SD__sc-zpgf61-0"
})(_ref => {
  var {
    theme
  } = _ref;
  return styled.css(["", "{&&{border-left:transparent;}}"], theme.breakpoints.up('sm'));
});
var ToolbarContent = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarContent__ToolbarContent",
  componentId: "SD__sc-zpgf61-1"
})(["flex:1;padding:16px;"]);
function SidebarContent(_ref2) {
  var {
    dense,
    action,
    title,
    children,
    onBack,
    openOnMount,
    closeOnUnmount
  } = _ref2;
  var isOpenedOnMount = react.useRef(false);
  var isClosedOnMount = react.useRef(false);
  var {
    openSidebarContent,
    openSidebar
  } = useSidebarContext();
  react.useLayoutEffect(() => {
    if (openOnMount) {
      if (isOpenedOnMount.current) {
        // eslint-disable-next-line no-console
        console.warn('[SidebarContent]: "openOnMount" should not change during lifecycle of the component.');
      } else {
        isOpenedOnMount.current = true;
        openSidebarContent();
      }
    }
  }, [openOnMount, openSidebarContent]);
  react.useLayoutEffect(() => {
    return () => {
      if (closeOnUnmount) {
        if (isClosedOnMount.current) {
          // eslint-disable-next-line no-console
          console.warn('[SidebarContent]: "closeOnUnmount" should not change during lifecycle of the component.');
        } else {
          isClosedOnMount.current = true;
          openSidebar();
        }
      }
    };
  }, [openSidebar, closeOnUnmount]);
  return /*#__PURE__*/jsxRuntime.jsxs(ui.Stack, {
    space: "none",
    children: [/*#__PURE__*/jsxRuntime.jsx(SidebarAppBar, {
      children: /*#__PURE__*/jsxRuntime.jsx(core.Toolbar, {
        disableGutters: true,
        children: /*#__PURE__*/jsxRuntime.jsx(ToolbarContent, {
          children: /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
            align: ['top', 'center'],
            space: "small",
            children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
              width: "content",
              children: /*#__PURE__*/jsxRuntime.jsx(SidebarBackButton, {
                onClick: onBack
              })
            }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
              children: /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
                space: "small",
                collapseBelow: "tablet",
                reverse: [true, false],
                align: ['bottom', 'center'],
                children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
                  children: /*#__PURE__*/jsxRuntime.jsx(TextBox, {
                    variant: "heading-2",
                    children: title
                  })
                }), action && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
                  width: "content",
                  children: action
                })]
              })
            })]
          })
        })
      })
    }), /*#__PURE__*/jsxRuntime.jsx(Box, {
      padding: dense ? 'none' : ['small', 'medium'],
      children: children
    })]
  });
}

var SidebarDividerRoot = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarDivider__SidebarDividerRoot",
  componentId: "SD__sc-5lwi2i-0"
})(["padding:20px 24px;"]);
var SidebarDivider = /*#__PURE__*/react.forwardRef((_, ref) => {
  return /*#__PURE__*/jsxRuntime.jsx(SidebarDividerRoot, {
    ref: ref,
    children: /*#__PURE__*/jsxRuntime.jsx(core.Divider, {})
  });
});
if (process.env.NODE_ENV !== "production") SidebarDivider.displayName = "SidebarDivider";

var context = /*#__PURE__*/react.createContext({});
function useSidebarMenuItemContext() {
  return react.useContext(context);
}
function SidebarMenuItemContextProvider(_ref) {
  var {
    children,
    hovered = false,
    disabled = false
  } = _ref;
  var ctx = react.useMemo(() => ({
    hovered,
    disabled
  }), [hovered, disabled]);
  return /*#__PURE__*/jsxRuntime.jsx(context.Provider, {
    value: ctx,
    children: children
  });
}

var SidebarMenuItemRoot = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarMenuItem__SidebarMenuItemRoot",
  componentId: "SD__sc-1sb5zqa-0"
})(_ref => {
  var {
    hasAvatar,
    theme
  } = _ref;
  var height = hasAvatar ? 48 : 40;
  var mode = theme.palette.type;
  var color = mode === 'dark' ? core.alpha(ui.Color.White, 0.08) : ui.ColorDynamic.Silver200;
  return styled.css(["position:relative;& > .MuiButtonBase-root{width:100%;display:flex;justify-content:flex-start;padding-left:24px;padding-right:24px;height:", "px;max-height:", "px;&[aria-current='true']{background-color:", ";box-shadow:inset 4px 0 0 ", ";}&:hover{background-color:", ";}}"], height, height, color, ui.ColorDynamic.Blue300, color);
});
var SidebarMenuItemBadge = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarMenuItem__SidebarMenuItemBadge",
  componentId: "SD__sc-1sb5zqa-1"
})(["font-size:12px;font-weight:500;line-height:16px;padding-left:4px;padding-right:4px;border-radius:100px;color:", ";background-color:", ";"], ui.ColorDynamic.Dark500, ui.ColorDynamic.Silver400);
var SidebarMenuItem = /*#__PURE__*/react.forwardRef((_ref2, ref) => {
  var {
    action,
    avatar,
    onClick: _onClick,
    external,
    children,
    disabled,
    selected,
    secondaryActions,
    badge: badgeProp,
    openContentOnClick
  } = _ref2;
  var [hovered, setHovered] = react.useState(false);
  var rootRef = react.useRef(null);
  var {
    openSidebarContent
  } = useSidebarContext();
  var {
    matches: isHoverSupported
  } = matchMedia('(hover: hover)');
  react.useLayoutEffect(() => {
    var rootNode = rootRef.current;
    if (rootNode) {
      if (isHoverSupported) {
        rootNode.addEventListener('mouseenter', () => {
          setHovered(true);
        });
        rootNode.addEventListener('mouseleave', () => {
          setHovered(false);
        });
      } else {
        setHovered(true);
      }
    }
  }, [isHoverSupported]);
  var badge = !badgeProp || !Number.isFinite(badgeProp) ? null : badgeProp > 999 ? '999+' : badgeProp;
  return /*#__PURE__*/jsxRuntime.jsx(SidebarMenuItemRoot, {
    ref: ui.mergeRefs(ref, rootRef),
    hasAvatar: !!avatar,
    children: /*#__PURE__*/jsxRuntime.jsx(core.ButtonBase, {
      disabled: disabled,
      "aria-current": selected,
      onClick: event => {
        _onClick === null || _onClick === void 0 ? void 0 : _onClick(event);
        if (!event.isDefaultPrevented() && openContentOnClick) {
          openSidebarContent();
        }
      },
      children: /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
        align: "center",
        space: "xsmall",
        children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
          children: /*#__PURE__*/jsxRuntime.jsx(ui.Columns, {
            align: "center",
            space: "xsmall",
            children: /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
              width: "fluid",
              children: /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
                align: "center",
                space: "xsmall",
                children: [!!avatar && /*#__PURE__*/jsxRuntime.jsx(SidebarMenuItemContextProvider, {
                  hovered: hovered,
                  disabled: disabled,
                  children: /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
                    width: "content",
                    children: avatar
                  })
                }), /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
                  width: "adaptive",
                  children: /*#__PURE__*/jsxRuntime.jsx(TextBox, {
                    variant: selected ? 'body-semibold' : 'body',
                    noWrap: true,
                    children: children
                  })
                }), external && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
                  width: "content",
                  children: /*#__PURE__*/jsxRuntime.jsx(icons.OpenInNew, {
                    color: "action",
                    fontSize: "small"
                  })
                })]
              })
            })
          })
        }), (!!action || !!secondaryActions) && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
          width: "content",
          children: /*#__PURE__*/jsxRuntime.jsxs(ui.Inline, {
            children: [(selected || hovered) && secondaryActions, action]
          })
        }), !!badge && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
          width: "content",
          children: /*#__PURE__*/jsxRuntime.jsx(SidebarMenuItemBadge, {
            children: badge
          })
        })]
      })
    })
  });
});
if (process.env.NODE_ENV !== "production") SidebarMenuItem.displayName = "SidebarMenuItem";

var SidebarMenuItemActionRoot = /*#__PURE__*/styled__default(core.IconButton).withConfig({
  displayName: "SidebarMenuItemAction__SidebarMenuItemActionRoot",
  componentId: "SD__sc-1n50gmv-0"
})(["& .MuiSvgIcon-root{font-size:16px;}"]);
var SidebarMenuItemAction = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    title,
    placement,
    children
  } = _ref;
  return /*#__PURE__*/jsxRuntime.jsx(core.Tooltip, {
    title: title,
    placement: placement,
    children: /*#__PURE__*/jsxRuntime.jsx(SidebarMenuItemActionRoot, {
      ref: ref,
      size: "small",
      edge: "end",
      children: children
    })
  });
});
if (process.env.NODE_ENV !== "production") SidebarMenuItemAction.displayName = "SidebarMenuItemAction";

function stopPropagation(event) {
  event.stopPropagation();
}
var SidebarMenuItemAvatarCheckbox = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarMenuItemAvatar__SidebarMenuItemAvatarCheckbox",
  componentId: "SD__sc-17mkvc7-0"
})(["margin:-5px;"]);
var SidebarMenuItemAvatar = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    children,
    value,
    onChange: _onChange
  } = _ref;
  var {
    hovered,
    disabled
  } = useSidebarMenuItemContext();
  var initials = react.useMemo(() => {
    var matches = children.match(/\b\w/g) || [];
    var first = matches.shift() || '';
    var last = matches.pop() || '';
    return (first + last).toUpperCase();
  }, [children]);
  if (value === true || hovered && value != null) {
    return /*#__PURE__*/jsxRuntime.jsx(SidebarMenuItemAvatarCheckbox, {
      children: /*#__PURE__*/jsxRuntime.jsx(core.Checkbox, {
        color: "primary",
        checked: value,
        disabled: disabled,
        onClick: stopPropagation,
        onMouseDown: stopPropagation,
        onTouchStart: stopPropagation,
        onChange: (_, checked) => {
          _onChange === null || _onChange === void 0 ? void 0 : _onChange(checked);
        }
      })
    });
  }
  return /*#__PURE__*/jsxRuntime.jsx(core.Avatar, {
    ref: ref,
    "aria-hidden": true,
    children: initials
  });
});
if (process.env.NODE_ENV !== "production") SidebarMenuItemAvatar.displayName = "SidebarMenuItemAvatar";

var SidebarSubheaderRoot = /*#__PURE__*/styled__default.div.withConfig({
  displayName: "SidebarSubheader__SidebarSubheaderRoot",
  componentId: "SD__sc-1r0xx76-0"
})(["display:flex;align-items:center;height:40px;max-height:40px;padding-left:24px;padding-right:24px;"]);
var SidebarSubheader = /*#__PURE__*/react.forwardRef((_ref, ref) => {
  var {
    id,
    action,
    children
  } = _ref;
  return /*#__PURE__*/jsxRuntime.jsx(SidebarSubheaderRoot, {
    ref: ref,
    children: /*#__PURE__*/jsxRuntime.jsxs(ui.Columns, {
      space: "xsmall",
      align: "center",
      children: [/*#__PURE__*/jsxRuntime.jsx(ui.Column, {
        children: /*#__PURE__*/jsxRuntime.jsx(TextBox, {
          id: id,
          variant: "heading-6",
          color: "secondary",
          noWrap: true,
          children: children
        })
      }), !!action && /*#__PURE__*/jsxRuntime.jsx(ui.Column, {
        width: "content",
        children: action
      })]
    })
  });
});
if (process.env.NODE_ENV !== "production") SidebarSubheader.displayName = "SidebarSubheader";

exports.Alert = Alert;
exports.AnchorButton = AnchorButton;
exports.Banner = Banner;
exports.Box = Box;
exports.Button = Button;
exports.ButtonArea = ButtonArea;
exports.Chat = Chat;
exports.ChatMessage = ChatMessage;
exports.Container = Container;
exports.DescriptionItem = DescriptionItem;
exports.DescriptionLineItem = DescriptionLineItem;
exports.DottedLine = DottedLine;
exports.FileDropZone = FileDropZone;
exports.FileListItem = FileListItem;
exports.FlagList = FlagList;
exports.FlagListItem = FlagListItem;
exports.LinkedText = LinkedText;
exports.MultilineText = MultilineText;
exports.Navbar = Navbar;
exports.NavbarAvatar = NavbarAvatar;
exports.NavbarBadge = NavbarBadge;
exports.NavbarBottomBar = NavbarBottomBar;
exports.NavbarItem = NavbarItem;
exports.NavbarLabel = NavbarLabel;
exports.NavbarList = NavbarList;
exports.NavbarMenu = NavbarMenu;
exports.NavbarMenuItem = NavbarMenuItem;
exports.Sidebar = Sidebar;
exports.SidebarBackButton = SidebarBackButton;
exports.SidebarContainer = SidebarContainer;
exports.SidebarContent = SidebarContent;
exports.SidebarDivider = SidebarDivider;
exports.SidebarMenuItem = SidebarMenuItem;
exports.SidebarMenuItemAction = SidebarMenuItemAction;
exports.SidebarMenuItemAvatar = SidebarMenuItemAvatar;
exports.SidebarSubheader = SidebarSubheader;
exports.TextBox = TextBox;
exports.formatBytes = formatBytes;
exports.toBytes = toBytes;
exports.useNavbarContext = useNavbarContext;
exports.useSidebarContext = useSidebarContext;
//# sourceMappingURL=index.js.map
