import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["disabled", "children", "hintText", "startIcon", "fallback", "accept", "maxSize", "maxFiles", "onDropRejected", "onDropAccepted"];
import { CircularProgress, SvgIcon } from '@material-ui/core';
import { Error } from '@material-ui/icons';
import { mdiUpload } from '@mdi/js';
import { CardButton, ColorDynamic, Column, Columns } from '@superdispatch/ui';
import { forwardRef, Suspense } from 'react';
import Dropzone from 'react-dropzone';
import styled from 'styled-components';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
export function toBytes(input, unit) {
  if (unit === 'gb') return input * (1 << 30);
  if (unit === 'mb') return input * (1 << 20);
  return input * (1 << 10);
}
var KILOBYTE = 1024;
var BYTE_UNITS = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
export function formatBytes(bytes) {
  if (bytes === 0) return '0 Bytes';
  var unitIndex = Math.floor(Math.log(bytes) / Math.log(KILOBYTE));
  var unit = BYTE_UNITS[unitIndex];
  return "".concat((bytes / Math.pow(KILOBYTE, unitIndex)).toFixed(2), " ").concat(unit);
}
var StyledCardButton = /*#__PURE__*/styled(CardButton).withConfig({
  displayName: "FileDropZone__StyledCardButton",
  componentId: "SD__sc-5p1fk0-0"
})(_ref => {
  var {
    status
  } = _ref;
  return {
    backgroundColor: status === 'active' ? ColorDynamic.Blue50 : undefined
  };
});
function UploadRejection(_ref2) {
  var {
    maxSize,
    rejection
  } = _ref2;
  var [error] = rejection.errors;
  if (!error) return null;
  return /*#__PURE__*/_jsxs(Columns, {
    align: "center",
    children: [/*#__PURE__*/_jsx(Column, {
      width: "content",
      children: /*#__PURE__*/_jsx(Error, {})
    }), /*#__PURE__*/_jsx(Column, {
      children: error.code === 'file-too-large' ? maxSize == null ? 'Attachment size is too large' : "Attachment size should be less than ".concat(formatBytes(maxSize)) : error.message
    })]
  });
}
export var FileDropZone = /*#__PURE__*/forwardRef((props, ref) => {
  var {
      // CardButton
      disabled = false,
      children: _children = 'Upload Attachments',
      hintText = 'or Drag & Drop files',
      startIcon = /*#__PURE__*/_jsx(SvgIcon, {
        children: /*#__PURE__*/_jsx("path", {
          d: mdiUpload
        })
      }),
      fallback = /*#__PURE__*/_jsx(CardButton, {
        ref: ref,
        disabled: true,
        startIcon: /*#__PURE__*/_jsx(CircularProgress, {
          size: "1em",
          color: "inherit"
        }),
        children: "Loading dependencies\u2026"
      }),
      // Dropzone
      accept,
      maxSize = Infinity,
      maxFiles = Infinity,
      onDropRejected: _onDropRejected,
      onDropAccepted: _onDropAccepted
    } = props,
    dropzoneProps = _objectWithoutProperties(props, _excluded);
  return /*#__PURE__*/_jsx(Suspense, {
    fallback: fallback,
    children: /*#__PURE__*/_jsx(Dropzone, _objectSpread(_objectSpread({}, dropzoneProps), {}, {
      accept: accept,
      maxSize: maxSize,
      maxFiles: maxFiles,
      disabled: disabled,
      onDropAccepted: files => {
        _onDropAccepted === null || _onDropAccepted === void 0 ? void 0 : _onDropAccepted(files);
      },
      onDropRejected: fileRejections => {
        _onDropRejected === null || _onDropRejected === void 0 ? void 0 : _onDropRejected(fileRejections);
      },
      children: _ref3 => {
        var {
          isDragActive,
          isDragReject,
          getRootProps,
          getInputProps,
          fileRejections: [fileRejection]
        } = _ref3;
        return /*#__PURE__*/_jsxs(_Fragment, {
          children: [/*#__PURE__*/_jsx("input", _objectSpread({}, getInputProps())), /*#__PURE__*/_jsx(StyledCardButton, _objectSpread(_objectSpread({}, getRootProps()), {}, {
            ref: ref,
            hint: hintText,
            disabled: disabled,
            startIcon: startIcon,
            status: isDragActive ? 'active' : isDragReject ? 'error' : 'idle',
            error: !!fileRejection && /*#__PURE__*/_jsx(UploadRejection, {
              accept: accept,
              maxSize: maxSize,
              rejection: fileRejection
            }),
            children: _children
          }))]
        });
      }
    }))
  });
});
if (process.env.NODE_ENV !== "production") FileDropZone.displayName = "FileDropZone";