import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import { CircularProgress, IconButton, Link, SvgIcon, Tooltip } from '@material-ui/core';
import { CheckCircle, Delete, Error, Image, Refresh } from '@material-ui/icons';
import { mdiFilePdfBox, mdiTextBox } from '@mdi/js';
import { ColorDynamic, Column, Columns, useResponsiveValue, useUID } from '@superdispatch/ui';
import { forwardRef, memo, useState } from 'react';
import styled from 'styled-components';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
var FileListItemName = /*#__PURE__*/styled.div.withConfig({
  displayName: "FileListItem__FileListItemName",
  componentId: "SD__sc-hxbsiy-0"
})(["overflow:hidden;line-height:22px;white-space:nowrap;text-overflow:ellipsis;"]);
var FileListItemProgress = /*#__PURE__*/styled(CircularProgress).withConfig({
  displayName: "FileListItem__FileListItemProgress",
  componentId: "SD__sc-hxbsiy-1"
})(["font-size:24px;", "{font-size:14px;}"], _ref => {
  var {
    theme
  } = _ref;
  return theme.breakpoints.up('sm');
});
var PdfIcon = /*#__PURE__*/memo(props => /*#__PURE__*/_jsx(SvgIcon, _objectSpread(_objectSpread({}, props), {}, {
  children: /*#__PURE__*/_jsx("path", {
    d: mdiFilePdfBox
  })
})));
var TextBoxIcon = /*#__PURE__*/memo(props => /*#__PURE__*/_jsx(SvgIcon, _objectSpread(_objectSpread({}, props), {}, {
  children: /*#__PURE__*/_jsx("path", {
    d: mdiTextBox
  })
})));
var PDF_FILE_PATTERN = /\.pdf$/;
var IMAGE_FILE_PATTERN = /\.(gif|png|jpg|jpeg)$/;
function getFileType(name) {
  if (PDF_FILE_PATTERN.exec(name)) return 'pdf';
  if (IMAGE_FILE_PATTERN.exec(name)) return 'image';
  return 'unknown';
}
export var FileListItem = /*#__PURE__*/forwardRef((_ref2, ref) => {
  var {
    url,
    name,
    status,
    canDelete = true,
    onRetry,
    onDelete
  } = _ref2;
  var uid = useUID();
  var fileType = getFileType(name);
  var [isHoveredState, setIsHovered] = useState(false);
  var isHovered = useResponsiveValue(true, isHoveredState);
  return /*#__PURE__*/_jsx("div", {
    ref: ref,
    onMouseOver: () => {
      setIsHovered(true);
    },
    onMouseLeave: () => {
      setIsHovered(false);
    },
    "aria-label": "file-list-item",
    children: /*#__PURE__*/_jsxs(Columns, {
      align: "center",
      space: "xsmall",
      children: [/*#__PURE__*/_jsx(Column, {
        width: "content",
        children: status === 'error' ? /*#__PURE__*/_jsx(Error, {
          color: "error",
          fontSize: "small"
        }) : fileType === 'pdf' ? /*#__PURE__*/_jsx(PdfIcon, {
          color: "action",
          fontSize: "small"
        }) : fileType === 'image' ? /*#__PURE__*/_jsx(Image, {
          color: "action",
          fontSize: "small"
        }) : /*#__PURE__*/_jsx(TextBoxIcon, {
          color: "action",
          fontSize: "small"
        })
      }), /*#__PURE__*/_jsx(Column, {
        width: "fluid",
        children: /*#__PURE__*/_jsx(FileListItemName, {
          id: uid,
          children: !url ? name : /*#__PURE__*/_jsx(Link, {
            href: url,
            noWrap: true,
            target: "_blank",
            rel: "noopener noreferrer",
            children: name
          })
        })
      }), status === 'error' && /*#__PURE__*/_jsx(Column, {
        width: "content",
        children: /*#__PURE__*/_jsx(Tooltip, {
          title: "Retry",
          children: /*#__PURE__*/_jsx(IconButton, {
            size: "small",
            onClick: onRetry,
            children: /*#__PURE__*/_jsx(Refresh, {
              fontSize: "small"
            })
          })
        })
      }), /*#__PURE__*/_jsx(Column, {
        width: "content",
        children: status === 'loading' ? /*#__PURE__*/_jsx(IconButton, {
          size: "small",
          disabled: true,
          children: /*#__PURE__*/_jsx(FileListItemProgress, {
            size: "1em"
          })
        }) : !isHovered && status === 'success' ? /*#__PURE__*/_jsx(IconButton, {
          size: "small",
          children: /*#__PURE__*/_jsx(CheckCircle, {
            fontSize: "small",
            htmlColor: ColorDynamic.Green300
          })
        }) : canDelete ? /*#__PURE__*/_jsx(Tooltip, {
          title: "Delete",
          children: /*#__PURE__*/_jsx(IconButton, {
            size: "small",
            onClick: onDelete,
            children: /*#__PURE__*/_jsx(Delete, {
              fontSize: "small"
            })
          })
        }) : null
      })]
    })
  });
});
if (process.env.NODE_ENV !== "production") FileListItem.displayName = "FileListItem";