import { alpha, ButtonBase } from '@material-ui/core';
import { OpenInNew } from '@material-ui/icons';
import { Color, ColorDynamic, Column, Columns, Inline, mergeRefs } from '@superdispatch/ui';
import { forwardRef, useLayoutEffect, useRef, useState } from 'react';
import styled, { css } from 'styled-components';
import { TextBox } from "../text-box/TextBox.js";
import { useSidebarContext } from "./SidebarContainer.js";
import { SidebarMenuItemContextProvider } from "./SidebarMenuItemContext.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
var SidebarMenuItemRoot = /*#__PURE__*/styled.div.withConfig({
  displayName: "SidebarMenuItem__SidebarMenuItemRoot",
  componentId: "SD__sc-1sb5zqa-0"
})(_ref => {
  var {
    hasAvatar,
    theme
  } = _ref;
  var height = hasAvatar ? 48 : 40;
  var mode = theme.palette.type;
  var color = mode === 'dark' ? alpha(Color.White, 0.08) : ColorDynamic.Silver200;
  return css(["position:relative;& > .MuiButtonBase-root{width:100%;display:flex;justify-content:flex-start;padding-left:24px;padding-right:24px;height:", "px;max-height:", "px;&[aria-current='true']{background-color:", ";box-shadow:inset 4px 0 0 ", ";}&:hover{background-color:", ";}}"], height, height, color, ColorDynamic.Blue300, color);
});
var SidebarMenuItemBadge = /*#__PURE__*/styled.div.withConfig({
  displayName: "SidebarMenuItem__SidebarMenuItemBadge",
  componentId: "SD__sc-1sb5zqa-1"
})(["font-size:12px;font-weight:500;line-height:16px;padding-left:4px;padding-right:4px;border-radius:100px;color:", ";background-color:", ";"], ColorDynamic.Dark500, ColorDynamic.Silver400);
export var SidebarMenuItem = /*#__PURE__*/forwardRef((_ref2, ref) => {
  var {
    action,
    avatar,
    onClick: _onClick,
    external,
    children,
    disabled,
    selected,
    secondaryActions,
    badge: badgeProp,
    openContentOnClick
  } = _ref2;
  var [hovered, setHovered] = useState(false);
  var rootRef = useRef(null);
  var {
    openSidebarContent
  } = useSidebarContext();
  var {
    matches: isHoverSupported
  } = matchMedia('(hover: hover)');
  useLayoutEffect(() => {
    var rootNode = rootRef.current;
    if (rootNode) {
      if (isHoverSupported) {
        rootNode.addEventListener('mouseenter', () => {
          setHovered(true);
        });
        rootNode.addEventListener('mouseleave', () => {
          setHovered(false);
        });
      } else {
        setHovered(true);
      }
    }
  }, [isHoverSupported]);
  var badge = !badgeProp || !Number.isFinite(badgeProp) ? null : badgeProp > 999 ? '999+' : badgeProp;
  return /*#__PURE__*/_jsx(SidebarMenuItemRoot, {
    ref: mergeRefs(ref, rootRef),
    hasAvatar: !!avatar,
    children: /*#__PURE__*/_jsx(ButtonBase, {
      disabled: disabled,
      "aria-current": selected,
      onClick: event => {
        _onClick === null || _onClick === void 0 ? void 0 : _onClick(event);
        if (!event.isDefaultPrevented() && openContentOnClick) {
          openSidebarContent();
        }
      },
      children: /*#__PURE__*/_jsxs(Columns, {
        align: "center",
        space: "xsmall",
        children: [/*#__PURE__*/_jsx(Column, {
          children: /*#__PURE__*/_jsx(Columns, {
            align: "center",
            space: "xsmall",
            children: /*#__PURE__*/_jsx(Column, {
              width: "fluid",
              children: /*#__PURE__*/_jsxs(Columns, {
                align: "center",
                space: "xsmall",
                children: [!!avatar && /*#__PURE__*/_jsx(SidebarMenuItemContextProvider, {
                  hovered: hovered,
                  disabled: disabled,
                  children: /*#__PURE__*/_jsx(Column, {
                    width: "content",
                    children: avatar
                  })
                }), /*#__PURE__*/_jsx(Column, {
                  width: "adaptive",
                  children: /*#__PURE__*/_jsx(TextBox, {
                    variant: selected ? 'body-semibold' : 'body',
                    noWrap: true,
                    children: children
                  })
                }), external && /*#__PURE__*/_jsx(Column, {
                  width: "content",
                  children: /*#__PURE__*/_jsx(OpenInNew, {
                    color: "action",
                    fontSize: "small"
                  })
                })]
              })
            })
          })
        }), (!!action || !!secondaryActions) && /*#__PURE__*/_jsx(Column, {
          width: "content",
          children: /*#__PURE__*/_jsxs(Inline, {
            children: [(selected || hovered) && secondaryActions, action]
          })
        }), !!badge && /*#__PURE__*/_jsx(Column, {
          width: "content",
          children: /*#__PURE__*/_jsx(SidebarMenuItemBadge, {
            children: badge
          })
        })]
      })
    })
  });
});
if (process.env.NODE_ENV !== "production") SidebarMenuItem.displayName = "SidebarMenuItem";