import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["variant", "as", "align", "color", "display", "noWrap", "wrapOverflow"];
import { ColorDynamic, parseResponsiveProp } from '@superdispatch/ui';
import { forwardRef } from 'react';
import styled, { css } from 'styled-components';
import { mergeStyles } from "../utils/mergeStyles.js";
import { createRuleNormalizer } from "../utils/RuleNormalizer.js";
import { jsx as _jsx } from "react/jsx-runtime";
var normalizeTextColor = /*#__PURE__*/createRuleNormalizer({
  inherit: 'inherit',
  primary: ColorDynamic.Dark500,
  secondary: ColorDynamic.Dark300,
  'light-gray': ColorDynamic.Dark100,
  //*deprecated use disabled instead
  disabled: ColorDynamic.Dark100,
  white: ColorDynamic.White,
  blue: ColorDynamic.Blue500,
  green: ColorDynamic.Green500,
  purple: ColorDynamic.Purple500,
  red: ColorDynamic.Red500,
  teal: ColorDynamic.Teal500,
  yellow: ColorDynamic.Yellow500
});
var VARIANT_TYPE_MAPPING = {
  'heading-1': 'h1',
  'heading-2': 'h2',
  'heading-3': 'h3',
  'heading-4': 'h4',
  'heading-5': 'h5',
  'heading-6': 'h6',
  body: 'span',
  'body-block': 'p',
  'body-semibold': 'span',
  caption: 'span',
  hint: 'span'
};
function variantMixin(_ref, variant) {
  var {
    typography,
    breakpoints
  } = _ref;
  switch (variant) {
    case 'heading-1':
      return typography.h1;
    case 'heading-2':
      return typography.h2;
    case 'heading-3':
      return typography.h3;
    case 'heading-4':
      return typography.h4;
    case 'heading-5':
      return typography.h5;
    case 'heading-6':
      return typography.h6;
    case 'body':
    default:
      return typography.body2;
    case 'body-block':
      {
        return mergeStyles({}, typography.body2, {
          lineHeight: '24px',
          [breakpoints.only('xs')]: {
            lineHeight: '28px'
          }
        });
      }
    case 'body-semibold':
      return typography.body1;
    case 'caption':
      return typography.caption;
    case 'hint':
      return mergeStyles({}, typography.caption, {
        lineHeight: '20px',
        fontSize: '13px'
      });
  }
}
function textBoxMixin(noWrap, align, color, display, wrapOverflow) {
  return css(["text-align:", ";color:", ";display:", ";overflow:", ";white-space:", ";overflow-wrap:", ";"], align, normalizeTextColor(color), display === 'initial' && (noWrap || align !== 'left') ? 'block' : display, noWrap ? 'hidden' : 'visible', noWrap ? 'nowrap' : 'normal', wrapOverflow ? 'break-word' : 'normal');
}
var TextBoxRoot = /*#__PURE__*/styled.span.withConfig({
  displayName: "TextBox__TextBoxRoot",
  componentId: "SD__sc-9mywck-0"
})(_ref2 => {
  var {
    theme,
    $noWrap,
    $variant,
    $align,
    $color,
    $display,
    $wrapOverflow
  } = _ref2;
  return css(["margin:0;padding:0;text-overflow:ellipsis;", ";", ";", "{", ";}", "{", ";}"], variantMixin(theme, $variant), textBoxMixin($noWrap[0], $align[0], $color[0], $display[0], $wrapOverflow[0]), theme.breakpoints.up('sm'), textBoxMixin($noWrap[1], $align[1], $color[1], $display[1], $wrapOverflow[1]), theme.breakpoints.up('md'), textBoxMixin($noWrap[2], $align[2], $color[2], $display[2], $wrapOverflow[2]));
});
export var TextBox = /*#__PURE__*/forwardRef((_ref3, ref) => {
  var {
      variant: $variant = 'body',
      as = VARIANT_TYPE_MAPPING[$variant],
      align = 'left',
      color = 'primary',
      display = 'initial',
      noWrap = false,
      wrapOverflow = false
    } = _ref3,
    props = _objectWithoutProperties(_ref3, _excluded);
  var $align = parseResponsiveProp(align);
  var $color = parseResponsiveProp(color);
  var $noWrap = parseResponsiveProp(noWrap);
  var $display = parseResponsiveProp(display);
  var $wrapOverflow = parseResponsiveProp(wrapOverflow);
  return /*#__PURE__*/_jsx(TextBoxRoot, _objectSpread(_objectSpread({}, props), {}, {
    as: as,
    ref: ref,
    $align: $align,
    $color: $color,
    $noWrap: $noWrap,
    $display: $display,
    $variant: $variant,
    $wrapOverflow: $wrapOverflow
  }));
});
if (process.env.NODE_ENV !== "production") TextBox.displayName = "TextBox";